<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'activer_plugin' => 'Plugin aktivieren',
'affichage' => 'Anzeigen',
'aide_non_disponible' => 'Teil der Online-Hilfe in dieser Sprache noch nicht verf&uuml;gbar.',
'auteur' => 'Autor:',
'avis_acces_interdit' => 'Zugang verweigert.',
'avis_article_modifie' => 'Achtung, @nom_auteur_modif@ hat vor @date_diff@ Minute(n) an diesem Artikel gearbeitet.',
'avis_aucun_resultat' => 'Kein Ergebnis.',
'avis_chemin_invalide_1' => 'Der gew&auml;hlte Pfad',
'avis_chemin_invalide_2' => 'scheint nicht zu stimmen. Bitte kehren Sie zur vorigen Seite zur&uuml;ck und &uuml;berpr&uuml;fen Sie die Angaben.',
'avis_connexion_echec_1' => 'Die Verbindung zum SQL-Server ist fehlgeschlagen.',
'avis_connexion_echec_2' => 'Kehren Sie zur vorigen Seite zur&uuml;ck und &uuml;berpr&uuml;fen Sie die Angaben.',
'avis_connexion_echec_3' => '<b>N.B.</b> Bei vielen Servern m&uuml;ssen Sie Ihre Datenbank ausdr&uuml;cklich <b>freischalten lassen</b> um sie nutzen zu k&ouml;nnen. Falls die Verbindung wieder fehlschl&auml;gt, stellen Sie bitte sicher, dass Ihre Datenbank freigeschaltet wurde.',
'avis_connexion_ldap_echec_1' => 'Die Verbindung zum LDAP-Server ist fehlgeschlagen.',
'avis_connexion_ldap_echec_2' => 'Kehren Sie zur vorigen Seite zur&uuml;ck und &uuml;berpr&uuml;fen Sie die Angaben.',
'avis_connexion_ldap_echec_3' => 'Sie k&ouml;nnen Benutzer auch ohne LDAP-Support importieren.',
'avis_conseil_selection_mot_cle' => '<b>Wichtige Kategorie:</b> Bitte w&auml;hlen Sie ein Schl&uuml;sselwort dieser Gruppe.',
'avis_deplacement_rubrique' => 'Achtung! diese Rubrik enth&auml;lt @contient_breves@ Meldungen@scb@: wenn Sie Rubrik verschieben wollen, markieren Sie bitte zur Best&auml;tigung dieses K&auml;stchen.',
'avis_destinataire_obligatoire' => 'Sie m&uuml;ssen einen Empf&auml;nger angeben, bevor Sie die Nachricht abschicken.',
'avis_doublon_mot_cle' => 'Dieses Schlagwort gibt es bereits. Wollen sie es wirklich anlegen?', # MODIF
'avis_erreur_connexion_mysql' => 'Verbindungsfehler (SQL)',
'avis_erreur_version_archive' => '<b>Achtung! Die Datei @archive@ entspricht nicht der von Ihnen installierten Version von SPIP.</b> Sie riskieren die Funktionalit&auml;t Ihrer Website zu beeintr&auml;chtigen oder sogar die Datenbank zu zerst&ouml;ren. Bitte brechen Sie den Vorgang jetzt ab.<p> Mehr dazu finden Sie in der <a href="@spipnet@"> franz&ouml;sischen SPIP-Dokumentation</a>.',
'avis_espace_interdit' => '<b>Gesperrter Bereich</b><div>SPIP ist bereits installiert.</div>',
'avis_lecture_noms_bases_1' => 'Das Installationsprogramm konnte die Namen der vorhandenen Datenbanken nicht lesen.',
'avis_lecture_noms_bases_2' => 'Entweder ist keine Datenbank vorhanden oder die Funktion zum Auflisten der Datenbanken ist abgeschaltet (Das ist bei vielen Webhostern der Fall).',
'avis_lecture_noms_bases_3' => 'Im zweiten Fall ist wahrscheinlich eine Datenbank vorhanden, die Ihren Anmeldenamen tr&auml;gt:',
'avis_non_acces_message' => 'Sie haben keinen Zugriff auf diese Nachricht.',
'avis_non_acces_page' => 'Sie haben keinen Zugriff auf diese Seite.',
'avis_operation_echec' => 'Operation fehlgeschlagen.',
'avis_operation_impossible' => 'Aktion nicht m&ouml;glich',
'avis_probleme_archive' => 'Fehler beim Lesen der Archivdatei @archive@',
'avis_site_introuvable' => 'Website nicht auffindbar',
'avis_site_syndique_probleme' => 'Achtung! Bei der Syndikation dieser Website ist ein Problem aufgetreten und das System ist vor&uuml;bergehend unterbrochen. &Uuml;berpr&uuml;fen Sie die Adresse der backend-Datei der Website (<b>@url_syndic@</b>) und versuchen Sie, die Informationen erneut abzurufen.',
'avis_sites_probleme_syndication' => 'Es gab ein Problem mit der Syndikation dieser Websites',
'avis_sites_syndiques_probleme' => 'Es gab ein Problem mit der Syndikation dieser Websites',
'avis_suppression_base' => 'ACHTUNG, Daten werden unwiderruflich gel&ouml;scht.',
'avis_version_mysql' => 'Ihre SQL-Version (@version_mysql@) erlaubt keine automatische Reparatur der Tabellen.',

// B
'bouton_acces_ldap' => 'LDAP Zugang hinzuf&uuml;gen',
'bouton_ajouter' => 'Hinzuf&uuml;gen',
'bouton_ajouter_participant' => 'TEILNEHMER HINZUF&Uuml;GEN:',
'bouton_annonce' => 'ANK&Uuml;NDIGUNG',
'bouton_annuler' => 'Abbrechen',
'bouton_checkbox_envoi_message' => 'Verschicken einer Nachricht erm&ouml;glichen',
'bouton_checkbox_indiquer_site' => 'obligatorische Angabe einer Website',
'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'Administratoren der Website',
'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'Redakteure',
'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'Besucher der Website die einen Beitrag in ein Forum geschrieben haben.',
'bouton_checkbox_signature_unique_email' => 'eine einzige Unterschrift pro E-Mail Adresse',
'bouton_checkbox_signature_unique_site' => 'eine einzige Unterschrift pro Website',
'bouton_demande_publication' => 'Artikel zur Ver&ouml;ffentlichung vorschlagen',
'bouton_desactive_tout' => 'Alles deaktivieren',
'bouton_desinstaller' => 'Deinstallieren',
'bouton_effacer_index' => 'Indexe l&ouml;schen',
'bouton_effacer_statistiques' => 'Statistiken l&ouml;schen',
'bouton_effacer_tout' => 'ALLES l&ouml;schen',
'bouton_envoi_message_02' => 'NACHRICHT SENDEN',
'bouton_envoyer_message' => 'Nachricht fertig: Senden',
'bouton_forum_petition' => 'FORUM + PETITION',
'bouton_modifier' => '&Auml;ndern',
'bouton_pense_bete' => 'PERS&Ouml;NLICHER MERKZETTEL',
'bouton_radio_activer_messagerie' => 'Interne Nachrichten aktivieren',
'bouton_radio_activer_messagerie_interne' => 'Interne Nachrichten aktivieren',
'bouton_radio_activer_petition' => 'Petitionen aktivieren',
'bouton_radio_afficher' => 'Anzeigen',
'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Auf der Liste angemeldeter Redakteure anzeigen',
'bouton_radio_articles_futurs' => 'nur f&uuml;r neue Artikel (hat keine Auswirkungen auf die Datenbank).',
'bouton_radio_articles_tous' => 'f&uuml;r ausnahmslos alle Artikel.',
'bouton_radio_articles_tous_sauf_forum_desactive' => 'nur f&uuml;r Artikel mit aktiviertem Forum.',
'bouton_radio_desactiver_messagerie' => 'Nachrichten abschalten',
'bouton_radio_enregistrement_obligatoire' => 'Obligatorische Anmeldung (Besucher m&uuml;ssen sich mit einer g&uuml;ltigen E-Mail Adresse anmelden, um Forumsbeitr&auml;ge schreiben zu k&ouml;nnen).',
'bouton_radio_envoi_annonces_adresse' => 'Editorische Ank&uuml;ndigungen an diese Adresse senden:',
'bouton_radio_envoi_liste_nouveautes' => 'Liste der neuesten Ver&ouml;ffentlichungen verschicken',
'bouton_radio_moderation_priori' => 'Vorgeschaltete Moderation (Die Benutzerkommentare werden erst nach Best&auml;tigung durch einen Administrator sichtbar). ',
'bouton_radio_modere_abonnement' => 'Mit Anmeldung',
'bouton_radio_modere_posteriori' => 'Nachtr&auml;gliche Moderation',
'bouton_radio_modere_priori' => 'Vorgeschaltete Moderation',
'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Ich will nicht auf dieser Liste zu sehen sein.',
'bouton_radio_non_envoi_annonces_editoriales' => 'Keine editorischen Ank&uuml;ndigungen verschicken',
'bouton_radio_non_syndication' => 'Syndikation nicht verwenden',
'bouton_radio_pas_petition' => 'Keine Petition',
'bouton_radio_petition_activee' => 'Petition aktiviert',
'bouton_radio_publication_immediate' => 'Sofortige Ver&ouml;ffentlichung von Beitr&auml;gen (sie werden sofort nach dem Absenden angezeigt und k&ouml;nnen von Administratoren nachtr&auml;glich gel&ouml;scht werden).',
'bouton_radio_sauvegarde_compressee' => 'komprimiert sichern nach @fichier@',
'bouton_radio_sauvegarde_non_compressee' => 'unkomprimiert sichern nach @fichier@',
'bouton_radio_supprimer_petition' => 'Petition l&ouml;schen',
'bouton_radio_syndication' => 'Syndikation:',
'bouton_redirection' => 'UMLEITUNG',
'bouton_relancer_installation' => 'Installation wiederholen',
'bouton_restaurer_base' => 'Datenbank wieder herstellen',
'bouton_suivant' => 'weiter',
'bouton_tenter_recuperation' => 'Reparatur versuchen',
'bouton_test_proxy' => 'Proxy testen',
'bouton_vider_cache' => 'Cache leeren',
'bouton_voir_message' => 'Beitrag vor dem Absenden ansehen',

// C
'cache_mode_compresse' => 'Cache-Dateien werden komprimiert gespeichert.',
'cache_mode_non_compresse' => 'Cache-Dateien werden unkomprimiert gespeichert.',
'cache_modifiable_webmestre' => 'Dieser Parameter kann vom Webmaster eingestellt werden.',
'calendrier_synchro' => 'Wenn Sie eine mit <b>iCal</b> kompatibles PIM-Programm verwenden, k&ouml;nne Sie es mit den Eintr&auml;gen dieser Website synchronisieren.',
'config_activer_champs' => 'Aktivieren Sie folgende Felder',
'config_choix_base_sup' => 'Eine Datenbank auf diesem Server angeben',
'config_erreur_base_sup' => 'SPIP kann nicht auf die Liste der verf&uuml;gbaren Datenbanken zugreifen.',
'config_info_base_sup' => 'Wenn Sie andere Datenbanken auf dem selben Server oder auf einem anderen mit SPIP abfragen m&ouml;chten, k&ouml;nnen Sie sie mit dem Formular weiter unten deklarieren. Wenn Sie Felder leer lassen, werden die Verbindungsdaten der Hauptdatenbank verwendet.',
'config_info_base_sup_disponibles' => 'Bereits abfragbare Datenbanken:',
'config_info_enregistree' => 'Neue Einstellungen wurden gespeichert',
'config_info_logos' => 'Jedes Element der Website kann ein Logo und ein &laquo;mouseover-Logo&raquo; erhalten.',
'config_info_logos_utiliser' => 'Logos verwenden',
'config_info_logos_utiliser_non' => 'Logos nicht verwenden',
'config_info_logos_utiliser_survol' => 'Mouseover-Logos verwenden',
'config_info_logos_utiliser_survol_non' => 'Mouseover-Logos nicht verwenden',
'config_info_redirection' => 'Mit dieser Option k&ouml;nnen Sie virtuelle Artikel anlegen, die als Weiterleitung zu Artikeln anderer Websites oder ausserhalb von SPIP funktionieren.',
'config_redirection' => 'Virtuelle Artikel',
'config_titre_base_sup' => 'Deklaration einer zus&auml;tzlichen Datenbank',
'config_titre_base_sup_choix' => 'W&auml;hlen Sie eine zus&auml;tzliche Datenbank',
'connexion_ldap' => 'Verbindung:',
'copier_en_local' => 'Lokale Koipe',

// D
'date_mot_heures' => 'Stunden',
'diff_para_ajoute' => 'Neuer Absatz',
'diff_para_deplace' => 'Absatz verschoben',
'diff_para_supprime' => 'Absatz gel&ouml;scht',
'diff_texte_ajoute' => 'Neuer Text',
'diff_texte_deplace' => 'Text verschoben',
'diff_texte_supprime' => 'Text gel&ouml;scht',
'double_clic_inserer_doc' => 'M&uuml;gen Sie mit einem Doppelklick das K&uuml;rzel in den Text ein',

// E
'email' => 'E-Mail',
'email_2' => 'E-Mail:',
'en_savoir_plus' => 'Weitere Informationen',
'entree_adresse_annuaire' => 'Adresse des Verzeichnisses',
'entree_adresse_email' => 'Ihre E-Mail Adresse',
'entree_adresse_fichier_syndication' => 'Adresse der &#132;backend&#147;-Datei:',
'entree_adresse_site' => '<b>Adresse der Website</b> [Pflichtfeld]',
'entree_base_donnee_1' => 'Adresse des Datenbankservers',
'entree_base_donnee_2' => '(Oftmals entspricht diese Adresse der Ihrer Website, sie kann auch einfach &bdquo;localhost&ldquo; lauten und gelegentlich darf das Feld leer bleiben.)',
'entree_biographie' => 'Ganz kurze Vorstellung / Lebenslauf',
'entree_breve_publiee' => 'Soll diese Meldung ver&ouml;ffentlicht werden?',
'entree_chemin_acces' => 'Bitte den <b>Pfad angeben</b>:',
'entree_cle_pgp' => 'Ihr &ouml;ffentlicher PGP-Schl&uuml;ssel',
'entree_contenu_rubrique' => '(Inhalt der Rubrik)',
'entree_description_site' => 'Beschreibung der Website',
'entree_identifiants_connexion' => 'Ihre Verbindungsdaten ...',
'entree_informations_connexion_ldap' => 'Bitte tragen Sie in dieses Formular die Zugangsdaten zu Ihrem LDAP-Verzeichnis ein. Sie erhalten diese Informationen von Ihrem System- oder Netzwerkadministrator.',
'entree_infos_perso' => 'Wer sind Sie?',
'entree_interieur_rubrique' => 'In der Rubrik:',
'entree_liens_sites' => '<b>Hyperlink</b> (Quelle, Website zum Thema ...)',
'entree_login' => 'Ihr Login-Name',
'entree_login_connexion_1' => 'Login f&uuml;r die Verbindung',
'entree_login_connexion_2' => '(Dieser entspricht h&auml;ufig Ihrem FTP-Login, bleibt in manchen F&auml;llen leer)',
'entree_login_ldap' => 'LDAP Basis-Login',
'entree_mot_passe' => 'Ihr Passwort',
'entree_mot_passe_1' => 'Passwort f&uuml;r die Verbindung',
'entree_mot_passe_2' => '(Entspricht h&auml;ufig Ihrem FTP-Login, bleibt in manchen F&auml;llen leer)',
'entree_nom_fichier' => 'Bitte geben Sie den Namen der Datei @texte_compresse@ an:',
'entree_nom_pseudo' => 'Ihr Name oder Pseudonym',
'entree_nom_pseudo_1' => '(Ihr Name oder Nickname)',
'entree_nom_site' => 'Der Titel Ihrer Website',
'entree_nouveau_passe' => 'Neues Passwort',
'entree_passe_ldap' => 'Passwort',
'entree_port_annuaire' => 'Port (Nummer) des Verzeichnisses',
'entree_signature' => 'Unterschrift',
'entree_texte_breve' => 'Text der Meldung',
'entree_titre_obligatoire' => '<b>Titel</b> [Pflichtfeld]<br />',
'entree_url' => 'Adresse (URL) Ihrer Website',
'erreur_plugin_desinstalation_echouee' => 'Das Plugin konnte nicht deinstalliert werden. Sie m&uuml;ssen es auf jeden Fall deaktivieren.',
'erreur_plugin_fichier_absent' => 'Datei nicht vorhanden',
'erreur_plugin_fichier_def_absent' => 'Definitionsdatei nicht vorhanden',
'erreur_plugin_nom_fonction_interdit' => 'Unzul&auml;ssiger Funktionsname',
'erreur_plugin_nom_manquant' => 'Name des Plugin fehlt',
'erreur_plugin_prefix_manquant' => 'Namespace des Plugin nicht definiert',
'erreur_plugin_tag_plugin_absent' => '&lt;Plugin&gt; fehlt in der Definitionsdatei',
'erreur_plugin_version_manquant' => 'Version des Plugin fehlt',

// F
'forum_info_original' => 'Original',

// H
'htaccess_a_simuler' => 'Achtung: Ihr HTTP-Server ist so konfiguriert, da&szlig; er @htaccess@ Dateien ignoriert. Eine sichere Konfiguration des Servers erzielen sie, indem sie diese Einstellung &auml;ndern, oder indem sie die @Konstanten@ in der Datei mes_options.php so setzen, da&szlig; die Verzeichnisse au&szlig;erhalb des @document_root@ liegen.',
'htaccess_inoperant' => 'htaccess unwirksam',

// I
'ical_info1' => 'Diese Seite erm&ouml;glicht auf mehrere Arten an der Entwicklung der Website teilzunehmen.',
'ical_info2' => 'Um mehr &uuml;ber diese Techniken zu erfahren, lesen Sie bitte die <a href="@spipnet@">SPIP Dokumentation</a>.',
'ical_info_calendrier' => 'Sie verf&uuml;gen &uuml;ber zwei Kalender. Einer gibt Ihnen eine &Uuml;bersicht &uuml;ber die Website und alle dort ver&ouml;ffentlichten Artikel. Der zweite enth&auml;lt editorische Ank&uuml;ndigungen und Ihre pers&ouml;nlichen Nachrichten. Sie allein haben Zugriff auf ihn indem Sie Ihr Passwort eingeben. Sie k&ouml;nne es &auml;ndern, indem Sie Ihr Zugangspasswort f&uuml;r diese Website &auml;ndern.',
'ical_lien_rss_breves' => 'Syndikation der Meldungen dieser Website',
'ical_methode_http' => 'Download',
'ical_methode_webcal' => 'Synchronisieren (webcal://)',
'ical_texte_js' => 'Mit nur einer Zeile Javascript k&ouml;nnen Sie auf Ihrer Website die neuesten Artikel dieser Website anzeigen.',
'ical_texte_prive' => 'Dieser nur f&uuml;r Sie selbst zug&auml;ngliche Kalender h&auml;lt Sie auf dem Laufenden &uuml;ber die internen redaktionellen Vorg&auml;nge dieser Website (Aufgaben und pers&ouml;nliche Termine, vorgeschlagene Artikel und Meldungen ...).',
'ical_texte_public' => 'Dieser Kalender gibt Ihnen einen &Uuml;berblick &uuml;ber die Ereignisse im &ouml;ffentlichen Bereich der Website.',
'ical_texte_rss' => 'Sie k&ouml;nnen die Neuheiten dieser Website mit einem beliebigen Programm anzeigen, dass das Format XML/RSS (Rich Site Summary) beherrscht. SPIP nutz dieses Protokoll auch, um neue Eintr&auml;ge aus anderen Websites zu &uuml;bernehmen (sog. syndizierte Websites).',
'ical_titre_js' => 'Javascript',
'ical_titre_mailing' => 'Mailing-List',
'ical_titre_rss' => '"Backend" Datei',
'icone_activer_cookie' => 'Verwaltungs-Cookie setzen',
'icone_admin_plugin' => 'Plugin-Verwaltung',
'icone_afficher_auteurs' => 'Autoren anzeigen',
'icone_afficher_visiteurs' => 'Besucher anzeigen',
'icone_arret_discussion' => 'Aus dieser Diskussion aussteigen',
'icone_calendrier' => 'Kalender',
'icone_creation_groupe_mots' => 'Neue Schlagwort-Kategorie anlegen',
'icone_creation_mots_cles' => 'Neues Schlagwort anlegen',
'icone_creer_auteur' => 'Neuen Autor anlegen und diesem Artikel zuordnen',
'icone_creer_mot_cle' => 'Neues Schlagwort anlegen und mit diesem Artikel verkn&uuml;pfen',
'icone_creer_mot_cle_breve' => 'Schlagwort anlegen und dieser Meldung zuordnen.',
'icone_creer_mot_cle_rubrique' => 'Schlagwort anlegen und dieser Rubrik zuordnen.',
'icone_creer_mot_cle_site' => 'Schlagwort anlegen und dieser Website zuordnen.',
'icone_creer_rubrique_2' => 'Neue Rubrik anlegen',
'icone_ecrire_nouvel_article' => 'Meldungen in dieser Rubrik',
'icone_envoyer_message' => 'Nachricht abschicken',
'icone_evolution_visites' => 'Besuchsentwicklung<br />@visites@ Abrufe',
'icone_modif_groupe_mots' => 'Schlagwort-Kategorie bearbeiten',
'icone_modifier_article' => 'Artikel bearbeiten',
'icone_modifier_breve' => 'Meldung bearbeiten',
'icone_modifier_message' => 'Nachricht bearbeiten',
'icone_modifier_mot' => 'Schlagwort &auml;ndern',
'icone_modifier_rubrique' => 'Rubrik bearbeiten',
'icone_modifier_site' => 'Website bearbeiten',
'icone_poster_message' => 'Nachricht schicken',
'icone_publier_breve' => 'Meldung ver&ouml;ffentlichen',
'icone_referencer_nouveau_site' => 'Neue Website verlinken',
'icone_refuser_breve' => 'Kurzmeldung ablehnen',
'icone_relancer_signataire' => 'Unterzeichner erneut benachrichtigen',
'icone_retour' => 'Zur&uuml;ck',
'icone_retour_article' => 'Zur&uuml;ck zum Artikel',
'icone_suivi_forum' => '&Ouml;ffentliches Forum: @nb_forums@ Beitr&auml;ge',
'icone_supprimer_cookie' => 'Verwaltungs-Cookie l&ouml;schen',
'icone_supprimer_groupe_mots' => 'Schlagwort-Kategorie l&ouml;schen',
'icone_supprimer_rubrique' => 'Rubrik l&ouml;schen',
'icone_supprimer_signature' => 'Unterschrift l&ouml;schen',
'icone_valider_signature' => 'Unterschrift best&auml;tigen',
'icone_voir_sites_references' => 'Verlinkte Websites anzeigen',
'icone_voir_tous_mots_cles' => 'Alle Schlagworte anzeigen',
'image_administrer_rubrique' => 'Sie k&ouml;nnen diese Rubrik verwalten',
'info_1_article' => '1 Artikel',
'info_1_breve' => '1 Meldung',
'info_1_site' => '1 Website',
'info_activer_cookie' => 'Sie k&ouml;nnen ein <b>Verwaltungs-Cookie</b> setzen. Es erlaubt Ihnen, Artikel und Rubriken direkt aus der Website zu bearbeiten.',
'info_activer_forum_public' => '<i>Um die &ouml;ffentlichen Foren zu aktivieren, w&auml;hlen Sie bitte
 die Moderation im Standardmodus:</i>',
'info_admin_gere_rubriques' => 'Dieser Administrator verwaltet die folgenden Rubriken:',
'info_admin_gere_toutes_rubriques' => 'Dieser Administrator verwaltet <b>alle Rubriken</b>.',
'info_admin_statuer_webmestre' => 'Diesem Administrator Webmaster-Rechte geben',
'info_admin_webmestre' => 'Dieser Administrator ist <b>Webmaster</b>',
'info_administrateur' => 'Administrator',
'info_administrateur_1' => 'Administrator',
'info_administrateur_2' => 'der Website (<i>vorsichtig einsetzen</i>)',
'info_administrateur_site_01' => 'Wenn Sie Administrator der Website sind, bitte',
'info_administrateur_site_02' => 'auf diesen Link klicken.',
'info_administrateurs' => 'Administratoren',
'info_administrer_rubrique' => 'Sie k&ouml;nnen diese Rubrik verwalten',
'info_adresse' => 'an Adresse:',
'info_adresse_email' => 'E-MAIL ADRESSE:',
'info_adresse_url' => 'Adresse (URL) der &ouml;ffentlichen Website',
'info_afficher_visites' => 'Besuche anzeigen f&uuml;r:',
'info_affichier_visites_articles_plus_visites' => 'Besuche der <b>beliebtesten Artikel seit Start der Website</b> anzeigen:',
'info_aide_en_ligne' => 'SPIP Online-Hilfe',
'info_ajout_image' => 'Wenn Sie Bilder als Dokumente anlegen, die einem Artikel zugeordnet sind, kann SPIP automatisch (Miniatur-)Vorschaubilder dazu erstellen. Sie k&ouml;nnen so eine automatische Galerie oder Bildermappe einrichten.',
'info_ajout_participant' => 'Dieser Teilnehmer wurde hinzugef&uuml;gt:',
'info_ajouter_rubrique' => 'Eine weitere zu verwaltende Rubrik hinzuf&uuml;gen:',
'info_annonce_nouveautes' => 'Ank&uuml;ndigung der Neuigkeiten',
'info_anterieur' => 'vorige',
'info_appliquer_choix_moderation' => 'Moderationstyp anwenden:',
'info_article' => 'Artikel',
'info_article_2' => 'Artikel',
'info_article_a_paraitre' => 'Vordatierte Artikel, die noch nicht erschienen sind.',
'info_articles_02' => 'Artikel',
'info_articles_2' => 'Artikel',
'info_articles_auteur' => 'Alle Artikel dieses Autors',
'info_articles_lies_mot' => 'Alle Artikel zu diesem Schlagwort',
'info_articles_trouves' => 'Gefundene Artikel',
'info_articles_trouves_dans_texte' => 'Gefundene Artikel (im Text)',
'info_attente_validation' => 'Ihre zur Ver&ouml;ffentlichung vorgeschlagenen Artikel',
'info_aujourdhui' => 'heute: ',
'info_auteur_message' => 'AUTOR DES BEITRAGS:',
'info_auteurs' => 'Autoren',
'info_auteurs_par_tri' => 'Autoren@partri@',
'info_auteurs_trouves' => 'Gefundene Autoren',
'info_authentification_externe' => 'Externe Authentifizierung',
'info_avertissement' => 'Warnung',
'info_barre_outils' => 'mit Symbolleiste?',
'info_base_installee' => 'Die Struktur Ihrer Datenbank wurde angelegt.',
'info_base_restauration' => 'Datenbank wird wieder hergestellt.',
'info_bloquer' => 'sperren',
'info_breves' => 'Verwendet Ihre Website Meldungen?',
'info_breves_03' => 'Meldungen',
'info_breves_liees_mot' => 'Mit diesem Schlagwort verkn&uuml;pfte Meldungen',
'info_breves_touvees' => 'Gefundene Meldungen',
'info_breves_touvees_dans_texte' => 'Gefundene Meldungen (im Text)',
'info_changer_nom_groupe' => 'Namen dieser Kategorie &auml;ndern:',
'info_chapeau' => 'Kopf',
'info_chapeau_2' => 'Kopf:',
'info_chemin_acces_1' => 'Optionen: <b>Pfad im Verzeichnis</b>',
'info_chemin_acces_2' => 'Sie m&uuml;ssen jetzt den Pfad zu den Informationen im Verzeichnis angeben. Diese Information ist unbedingt erforderlich, um die Benutzerprofile im Verzeichnis lesen zu k&ouml;nnen.',
'info_chemin_acces_annuaire' => 'Optionen: <b>Pfad im Verzeichnis</b>',
'info_choix_base' => 'Schritt 3: ',
'info_classement_1' => ' von @liste@',
'info_classement_2' => 'von @liste@',
'info_code_acces' => 'Vergessen Sie ihre Zugangsdaten nicht!',
'info_comment_lire_tableau' => 'Interpretation der Tabelle',
'info_compresseur_gzip' => '<b>N.B.:</b> Wir empfehlen zu testen, ob der Provider bereits PHP-Skripte komprimiert. Dazu k&ouml;nnen Sie den Dienst @testgzip@ nutzen.',
'info_compresseur_texte' => 'Falls Ihr Server HTML Seiten nicht automatisch f&uuml;r die &Uuml;bertragung zum Websurfer komprimiert, k&ouml;nnen Sie hier versuchen, die Kompression zu erzeingen und so die Datenmenge der &uuml;bertragenen Seiten zu reduzieren. <b>Achtung</b> : Diese Einstellung kann manche Server merklich verlangsamen.',
'info_compresseur_titre' => 'Optimierung und Kompression',
'info_config_forums_prive' => 'Im Redaktionsbereich k&ouml;nnen Sie verschiedene Foren aktivieren:',
'info_config_forums_prive_admin' => 'Ein Forum nur f&uuml;r Administratoren der Site:',
'info_config_forums_prive_global' => 'Ein allgemeines Forum f&uuml;r alle Redakteure:',
'info_config_forums_prive_objets' => 'Ein Forum unter jedem Artikel, Meldung, verlinkten Website, etc.:',
'info_config_suivi' => 'Wenn es sich bei dieser Adresse um eine Mailing-Liste handelt, k&ouml;nnen Sie unten die Adresse angeben, unter der sich Teilnehmer der Website anmelden k&ouml;nnen. Es kann sich um den URL einer Webseite handeln (die ein Anmeldeformular enth&auml;lt) oder um eine E-Mail Adresse mit angeh&auml;ngtem Parameter (z.B. <tt>@adresse_suivi@?subject=subscribe</tt>):',
'info_config_suivi_explication' => 'Sie k&ouml;nnen die Mailing-Liste dieser Website abonnieren. Sie werden dann per E-Mail &uuml;ber neu zur Ver&ouml;ffentlichung vorgeschlagene Artikel informiert.',
'info_confirmer_passe' => 'Neues Passwort best&auml;tigen:',
'info_conflit_edition_avis_non_sauvegarde' => 'Achtung, die folgenden Felder wurden von anderen ge&auml;ndert. Ihre &Auml;nderungen in diesen Feldern wurden deshalb nicht gespeichert.',
'info_conflit_edition_differences' => 'Unterschiede:',
'info_conflit_edition_version_enregistree' => 'Die gespeicherte Fassung:',
'info_conflit_edition_votre_version' => 'Ihre Fassung:',
'info_connexion_base' => 'Test der Verbindung zur Datenbank',
'info_connexion_base_donnee' => 'Verbindung mit Ihrer Datenbank',
'info_connexion_ldap_ok' => 'Die LDAP-Verbindung wurde hergestellt.</b><p> Sie k&ouml;nnen mit dem n&auml;chsten Schritt fortfahren.',
'info_connexion_mysql' => 'Verbindung zur SQL-Datenbank',
'info_connexion_ok' => 'Die Verbindung wurde hergestellt.',
'info_contact' => 'Kontakt',
'info_contenu_articles' => 'Inhalt der Artikel',
'info_creation_mots_cles' => 'Hier verwalten Sie die Schlagworte der Website',
'info_creation_paragraphe' => '(Um einen Absatz einzuf&uuml;gen, lassen Sie einfach eine Zeile frei.)',
'info_creation_rubrique' => 'Bevor Sie Artikel schreiben k&ouml;nnen,<br /> m&uuml;ssen Sie eine Rubrik anlegen.<br />',
'info_creation_tables' => 'Anlegen der Datentabellen',
'info_creer_base' => 'Neue Datenbank <b>anlegen</b>:',
'info_dans_groupe' => 'In der Kategorie:',
'info_dans_rubrique' => 'In der Rubrik:',
'info_date_publication_anterieure' => 'Datum einer fr&uuml;heren Bearbeitung:',
'info_date_referencement' => 'DATUM DER VERLINKUNG DIESER WEBSITE:',
'info_delet_mots_cles' => 'Das Schlagwort <b>@titre_mot@</b> (@type_mot@) ist mit dem Artikel <b>@texte_lie@</b> verkn&uuml;pft. Sie m&uuml;ssen deshalb das L&ouml;schen ausdr&uuml;cklich best&auml;tigen:',
'info_derniere_etape' => 'Fertig!',
'info_derniere_syndication' => 'Datum der letzten Syndikation dieser Website: ',
'info_derniers_articles_publies' => 'Ihre letzten ver&ouml;ffentlichten Artikel',
'info_desactiver_forum_public' => '&Ouml;ffentliche Foren abschalten. Es ist immer noch m&ouml;glich, ein Forum f&uuml;r einen Artikel einzurichten. F&uuml;r Rubriken, Meldungen, etc. stehen dann keine Foren zur Verf&uuml;gung.',
'info_desactiver_messagerie_personnelle' => 'Sie k&ouml;nnen die Nutzung Ihrer pers&ouml;nlichen Nachrichten abschalten.',
'info_descriptif' => 'Beschreibung:',
'info_desinstaller_plugin' => 'l&ouml;scht die Daten und desktiviert das Plugin',
'info_discussion_cours' => 'Aktuelle Diskussionen',
'info_ecrire_article' => 'Bevor Sie Artikel schreiben k&ouml;nnnen, m&uuml;ssen Sie mindestens eine Rubrik anlegen.',
'info_email_envoi' => 'Absenderadresse (freiwillige Angabe)',
'info_email_envoi_txt' => 'Geben Sie hier die Absenderadresse der E-Mails an (ohne diese Angabe wird die Empf&auml;ngeradresse als Absender eingetragen). ',
'info_email_webmestre' => 'E-Mail des Webmasters (freiwillige Angabe)',
'info_entrer_code_alphabet' => 'Geben Sie die Bezeichnung des gew&uuml;nschten Zeichensatz an: ',
'info_envoi_email_automatique' => 'Automatischer Mailversand',
'info_envoi_forum' => 'Forumsbeitr&auml;ge an Autoren der Artikel schicken',
'info_envoyer_maintenant' => 'Jetzt schicken',
'info_erreur_restauration' => 'Fehler bei der Wiederherstellung: Datei nicht vorhanden.',
'info_etape_suivante' => 'Weiter',
'info_etape_suivante_1' => 'Sie k&ouml;nnen den n&auml;chsten Schritt ausf&uuml;hren.',
'info_etape_suivante_2' => 'Sie k&ouml;nnen den n&auml;chsten Schritt ausf&uuml;hren.',
'info_exportation_base' => 'Export der Datenbank nach @archive@',
'info_facilite_suivi_activite' => 'Um die editorische Arbeit zu erleichtern kann SPIP Ver&ouml;ffentlichungsvorschl&auml;ge und Freischaltungen z.B. an eine Mailing-Liste der Redakteure schicken.',
'info_fichiers_authent' => '&#8220;.htpasswd&#8221; Dateien',
'info_fonctionnement_forum' => 'Funktionsweise des Forums:',
'info_forum_administrateur' => 'Forum der Administratoren',
'info_forum_interne' => 'Internes Forum',
'info_forum_ouvert' => 'Im Redaktionssystem der Website gibt es ein Forum f&uuml;r alle Redakteure. Sie k&ouml;nnen hier ein Forum <i>nur f&uuml;r Administratoren</i> einschalten.',
'info_forum_statistiques' => 'Besucherstatistiken',
'info_forums_abo_invites' => 'Ihre Website hat Foren f&uuml;r eingetragene Teilnehmer. Ihre Leser werden aus diesem Gund aufgefordert, sich bei Ihrer Website anzumelden.',
'info_gauche_admin_effacer' => '<b>Diese Seite ist nur f&uuml;r den Verantwortlichen der Website zug&auml;nglich.</b><p>Sie erlaubt bestimmte technische Wartungsvorg&auml;nge auszul&ouml;sen. F&uuml;r manche Funktionen ist die Authentifizierung per FTP Voraussetzung.',
'info_gauche_admin_tech' => '<b>Diese Seite ist nur f&uuml;r den Verantwortlichen der Website zug&auml;nglich.</b><p>Sie erlaubt bestimmte technische Wartungsvorg&auml;nge auszul&ouml;sen. F&uuml;r manche Funktionen ist die Authentifizierung per FTP Voraussetzung.',
'info_gauche_admin_vider' => '<b>Diese Seite ist nur f&uuml;r den Verantwortlichen der Website zug&auml;nglich.</b><p>Sie erlaubt bestimmte technische Wartungsvorg&auml;nge auszul&ouml;sen. F&uuml;r manche Funktionen ist die Authentifizierung per FTP Voraussetzung.',
'info_gauche_auteurs' => 'Hier sehen Sie alle Autoren der Website.
Ihr Status wird durch die Farbe ihres Symbols angezeigt (Redakteur = gelb; Administrator = gr&uuml;n). ',
'info_gauche_auteurs_exterieurs' => 'Externe Autoren ohne Zugang zum Redaktionssystem werden mit einem blauen Symbol gekennzeichnet, gel&ouml;schte Autoren haben eine M&uuml;lltonne als Symbol.',
'info_gauche_messagerie' => 'Nachrichtensystem: SPIP erm&ouml;glicht den Austausch von Nachrichten zwischen Redakteuren, pers&ouml;nliche Merkzettel und Ank&uuml;ndigungen im privaten Arbeitsbereich der Redakteure (nur Administratoren k&ouml;nnen diese verschicken).',
'info_gauche_numero_auteur' => 'AUTOR NUMMER',
'info_gauche_numero_breve' => 'MELDUNG NUMMER',
'info_gauche_statistiques_referers' => 'Diese Seite zeigt Ihnen <i>REFERER</i>, d.h. Webadressen mit Links zu Ihrer Website. Angezeigt werden nur Links von gestern und heute, diese Liste wird alle 24 Stunden auf Null gesetzt.',
'info_gauche_suivi_forum' => 'Die Seite zum <i>Verwalten der Foren</i> hat eine administrative Funktion und dient nicht zum Diskutieren mit den Lesern. Es werden alle Eintr&auml;ge im &ouml;ffentlichen Forum des Artikels gezeigt, so dass Sie diese einzeln ein- und ausschalten k&ouml;nnen.',
'info_gauche_suivi_forum_2' => 'Die Seite zum <i>Verwalten der Foren</i> hat eine administrative Funktion und dient nicht zum Diskutieren mit den Lesern. Es werden alle Eintr&auml;ge in &ouml;ffentlichen und internen Foren gezeigt, so dass Sie diese einzeln ein- und ausschalten k&ouml;nnen.',
'info_gauche_visiteurs_enregistres' => 'Hier sehen Sie die im &ouml;ffentlichen Bereich der Website angemeldeten Besucher (Teilnahme an Foren nur mit g&uuml;ltiger E-Mail Adresse).',
'info_generation_miniatures_images' => 'Anlegen der Vorschaubilder',
'info_gerer_trad' => '&Uuml;bersetzungslinks verwalten?',
'info_groupe_important' => 'Wichtige Kategorie',
'info_hebergeur_desactiver_envoi_email' => 'Manche ISPs verhindern den Versand von Mails mit PHP. Die Mailfunktionen von SPIP funktionieren dann nicht.',
'info_hier' => 'Gestern:',
'info_historique' => 'Versionen:',
'info_historique_activer' => 'Versionskontrolle aktivieren',
'info_historique_affiche' => 'Version anzeigen',
'info_historique_comparaison' => 'Vergleich',
'info_historique_desactiver' => 'Versionskontrolle abschalten',
'info_historique_lien' => 'Versionen anzeigen',
'info_historique_texte' => 'Die Versionskontrolle erm&ouml;glicht es, alle &Auml;nderungen an einem Artikel aufzuzeichnen und die Unterschiede zwischen aufeinander folgenden Versionen anzuzeigen.',
'info_historique_titre' => 'Versionskontrolle',
'info_identification_publique' => 'Ihre &ouml;ffentliche Identit&auml;t ...',
'info_image_process' => 'Bitte w&auml;hlen Sie das beste Verfahren zum Generieren der Miniaturbilder, indem Sie auf ein Bild klicken.',
'info_image_process2' => '<b>Bemerkung:</b> <i>Wenn kein Bild angezeigt wird, ist der Server ihrer Website nicht f&uuml;r die Verwendung solcher Werkzeuge eingerichtet. Wenn Sie diese Funktionen nutzen m&ouml;chten, wenden Sie sich bitte an den verantwortlichen Techniker und bitten ihn, die Erweiterungen &laquo;GD&raquo; oder &laquo;Imagick&raquo; einzurichten.</i>',
'info_images_auto' => 'automatisch berechnete Bilder',
'info_informations_personnelles' => 'Pers&ouml;nliche Informationen',
'info_inscription_automatique' => 'Automatische Anmeldung neuer Redakteure',
'info_jeu_caractere' => 'Zeichensatz der Website',
'info_jours' => 'Tage',
'info_laisser_champs_vides' => 'diese Felder frei lassen)',
'info_langues' => 'Sprachen der Website',
'info_ldap_ok' => 'Die LDAP-Authentifizierung ist installiert.',
'info_lien_hypertexte' => 'Hyperlink:',
'info_liens_syndiques_1' => 'Links (Syndikation)',
'info_liens_syndiques_2' => 'warten auf Freigabe.',
'info_liens_syndiques_3' => 'Foren',
'info_liens_syndiques_4' => 'sind',
'info_liens_syndiques_5' => 'Forum',
'info_liens_syndiques_6' => 'ist',
'info_liens_syndiques_7' => 'warten auf Freigabe',
'info_liste_redacteurs_connectes' => 'Liste der zur Zeit angemeldeten Redakteure',
'info_login_existant' => 'Dieser Login-Name ist bereits vergeben.',
'info_login_trop_court' => 'Login-Name zu kurz.',
'info_logos' => 'Die Logos',
'info_maximum' => 'Maximum:',
'info_meme_rubrique' => 'In der gleichen Rubrik',
'info_message' => 'Nachricht vom ',
'info_message_efface' => 'NACHRICHT GEL&Ouml;SCHT',
'info_message_en_redaction' => 'IHRE NACHRICHTEN IN BEARBEITUNG',
'info_message_technique' => 'Technische Nachricht:',
'info_messagerie_interne' => 'Interne Nachrichten',
'info_mise_a_niveau_base' => 'Update Ihrer SQL-Datenbank',
'info_mise_a_niveau_base_2' => '{{ACHTUNG!}} Sie haben eine {&auml;ltere} Version der SPIP-Dateien installiert als sich vorher auf Ihrem Server befand. Ihre Datenbank wird m&ouml;glicherweise zerst&ouml;rt und Ihre Website wird nict mehr funktionieren.<br />{{Installieren Sie SPIP noch einmal.}}',
'info_mode_fonctionnement_defaut_forum_public' => 'Standardmodus der &ouml;ffentlichen Foren',
'info_modifier_auteur' => 'Autor bearbeiten:',
'info_modifier_breve' => 'Meldung bearbeiten:',
'info_modifier_mot' => 'Schlagwort &auml;ndern:',
'info_modifier_rubrique' => 'Rubrik bearbeiten:',
'info_modifier_titre' => 'Bearbeiten: @titre@',
'info_mon_site_spip' => 'Meine SPIP-Site',
'info_mot_sans_groupe' => '(Ohne Kategorie...)',
'info_moteur_recherche' => 'Integrierte Suchfunktion',
'info_mots_cles' => 'Schlagworte',
'info_mots_cles_association' => 'Schlagworte dieser Kategorie k&ouml;nnen zugeordnet werden:',
'info_moyenne' => 'Durchschnitt: ',
'info_multi_articles' => 'Sprachauswahl f&uuml;r Artikel aktivieren?',
'info_multi_cet_article' => 'Dieser Artikel ist auf:&nbsp;',
'info_multi_langues_choisies' => 'Bitte w&auml;hlen Sie hier die Sprachen aus, die den Redakteuren Ihrer Website zur Verf&uuml;gung stehen sollen. Die Sprachen, welche bereits in Ihrer Website verwendet werden (oben auf der Liste), k&ouml;nnen nicht abgeschaltet werden.',
'info_multi_rubriques' => 'Sprachauswahl f&uuml;r Rubriken aktivieren?',
'info_multi_secteurs' => '... nur f&uuml;r Rubriken der obersten Ebene?',
'info_nom' => 'Name',
'info_nom_destinataire' => 'Name des Empf&auml;ngers',
'info_nom_site' => 'Name Ihrer Website',
'info_nom_site_2' => '<b>Name der Website</b> [Pflichtfeld]',
'info_nombre_articles' => '@nb_articles@ Artikel,',
'info_nombre_breves' => '@nb_breves@ Kurzmeldugen, ',
'info_nombre_partcipants' => 'TEILNEHMER DER DISKUSSION:',
'info_nombre_rubriques' => '@nb_rubriques@ Rubriken, ',
'info_nombre_sites' => '@nb_sites@ Websites, ',
'info_non_deplacer' => 'Bitte nicht verschieben...',
'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP kann regelm&auml;&szlig;ig die letzten Neuigkeiten der Website verschicken. (vor Kurzem erschienene Artikel und Meldungen).',
'info_non_envoi_liste_nouveautes' => 'Keine Liste der Neuigkeiten verschicken.',
'info_non_modifiable' => 'kann nicht ge&auml;ndert werden.',
'info_non_suppression_mot_cle' => 'ich m&ouml;chte dieses Schlagwort nicht l&ouml;schen.',
'info_notes' => 'Notizen',
'info_nouveaux_message' => 'Neue Nachrichten',
'info_nouvel_article' => 'Neuer Artikel',
'info_nouvelle_traduction' => 'Neue &Uuml;bersetzung:',
'info_numero_article' => 'ARTIKEL NUMMER:',
'info_obligatoire_02' => '[Erforderlich]',
'info_option_accepter_visiteurs' => 'Besucher d&uuml;rfen sich als Leser der Website anmelden.',
'info_option_email' => 'Wenn ein Besucher einen Beitrag im Forum eines Artikels postet, kann SPIP ihn an den Autor des Artikels schicken. Bitte geben Sie f&uuml;r jeden Inhaltstyp an, ob sie diese Funktion nutzen m&ouml;chten.',
'info_option_faire_suivre' => 'Forumsbeitr&auml;ge an Autoren der Artikel schicken.',
'info_option_ne_pas_accepter_visiteurs' => 'Anmeldung von Lesern verhindern',
'info_option_ne_pas_faire_suivre' => 'Keine Beitr&auml;ge aus den Foren an die Autoren verschicken.',
'info_options_avancees' => 'SPEZIALFUNKTIONEN',
'info_ortho_activer' => 'Rechtschreibpr&uuml;fung aktivieren',
'info_ortho_desactiver' => 'Rechtschreibpr&uuml;fung abschalten',
'info_ou' => 'oder ... ',
'info_oui_suppression_mot_cle' => ' ich m&ouml;chte dieses Schlagwort endg&uuml;ltig l&ouml;schen.',
'info_page_interdite' => 'Seite gesperrt',
'info_par_nom' => 'nach Namen',
'info_par_nombre_article' => 'nach Anzahl der Artikel',
'info_par_statut' => 'nach Status',
'info_par_tri' => '\'(nach @tri@)\'',
'info_pas_de_forum' => 'kein Forum',
'info_passe_trop_court' => 'Passwort zu kurz.',
'info_passes_identiques' => 'Die zwei Passworte stimmen nicht &uuml;berein.',
'info_pense_bete_ancien' => 'Ihre alten Merkzettel',
'info_plus_cinq_car' => 'mehr als 5 Zeichen',
'info_plus_cinq_car_2' => '(mehr als 5 Zeichen)',
'info_plus_trois_car' => '(mehr als 3 Zeichen)',
'info_popularite' => 'Beliebtheit: @popularite@ ; Besuche: @visites@',
'info_popularite_2' => 'Beliebtheit der Website: ',
'info_popularite_3' => 'Beliebtheit: @popularite@ ; Besuche: @visites@',
'info_popularite_4' => 'Beliebtheit: @popularite@ ; Besuche: @visites@',
'info_post_scriptum' => 'Post-Scriptum',
'info_post_scriptum_2' => 'Post-scriptum:',
'info_pour' => 'f&uuml;r',
'info_preview_admin' => 'Nur Administratoren k&ouml;nnen die Vorschau nutzen',
'info_preview_comite' => 'Alle Redakteure k&ouml;nnen die Vorschau nutzen',
'info_preview_desactive' => 'Vorschau deaktiviert',
'info_preview_texte' => 'Man kann sich die Website so anzeigen lassen, als ob alle Artikel ver&ouml;ffentlicht w&auml;ren, die mindestens den Status &laquo;&nbsp;vorgeschlagen&nbsp;&raquo; haben. Wem soll diese M&ouml;glichkeit zur Verf&uuml;gung stehen (Adminsitratoren, Redakteure, niemand)?',
'info_principaux_correspondants' => 'Ihre wichtigsten Korrespondezpartner',
'info_procedez_par_etape' => 'gehen Sie Schritt f&uuml;r Schritt vor',
'info_procedure_maj_version' => 'Sie m&uuml;ssen die Update-Funktion starten, um Ihre Datenbank an die neue Version von SPIP anzupassen.',
'info_proxy_ok' => 'Proxytest erfolgreich.',
'info_ps' => 'P.S.',
'info_publier' => 'ver&ouml;ffentlichen',
'info_publies' => 'Ihre ver&ouml;ffentlichten Artikel',
'info_question_accepter_visiteurs' => 'Bitte aktivieren Sie die folgende Option, wenn sich Besucher Ihrer Website als <i>Leser ohne Zugang zum Redaktionssystem</i> anmelden k&ouml;nnen.',
'info_question_activer_compactage_css' => 'M&ouml;chten Sie die Stylesheets (CSS) komprimieren?',
'info_question_activer_compactage_js' => 'M&ouml;chten Sie die Javascripte komprimieren ?',
'info_question_activer_compresseur' => 'M&ouml;chten sie die HTTP-&Uuml;bertragung komprimieren?',
'info_question_gerer_statistiques' => 'Soll SPIP Besucherstatistiken anlegen?',
'info_question_inscription_nouveaux_redacteurs' => 'M&ouml;chten Sie, dass sich neue Redakteure vom &ouml;ffentlichen Bereich
 aus anmelden k&ouml;nnen?&nbsp; Wenn Sie es wollen, k&ouml;nnen sich Besucher &uuml;ber ein automatisch
 erstelltes Formular anmelden und Artikel vorschlagen.
 <blockquote><i>Nach der Anmeldung erhalten die neuen Redakteure automatisch
 eine E-Mail mit ihren Zugangsdaten. Manche Webhoster unterbinden den Mailversand
 von ihren Webservern aus.
 In diesem Fall funktioniert die automatische Anmeldung nicht.',
'info_question_mots_cles' => 'M&ouml;chten Sie Schlagworte f&uuml;r Ihre Website verwenden?',
'info_question_proposer_site' => 'Wer darf Websites zur Verlinkung vorschlagen?',
'info_question_utilisation_moteur_recherche' => 'Wollen Sie die integrierte Suchfunktion von SPIP verwenden? (ohne Suchfunktion wird Ihr System schneller.)',
'info_question_vignettes_referer' => 'Sie k&ouml;nnen die Besucherstatistiken mit Thumbnails der Herkunftswebsites (referer) erg&auml;nzen',
'info_question_vignettes_referer_non' => 'Keine Thumbnails der Herkunftswebsites anzeigen',
'info_question_vignettes_referer_oui' => 'Thumbnails der Herkunftswebsites anzeigen',
'info_question_visiteur_ajout_document_forum' => 'Wenn Sie den Besuchern gestatten, ihren Forumsbeitr&auml;gen Dokumente (T&ouml;ne, Bilder, ...) beizuf&uuml;gen, w&auml;hlen Sie bitte aus der Liste die erlaubten Formate (z.B. gif, jpg, png, mp3).',
'info_question_visiteur_ajout_document_forum_format' => 'Wenn Sie alle von SPIP akzeptierten Dateitypen zulassen m&ouml;chten, geben Sie bitte einen Asterisk (*) ein. Wenn Sie keine Dokumente zulassen m&ouml;chten, tragen Sie keinen Wert ein.',
'info_qui_attribue_mot_cle' => 'Schlagworte dieser Kategorie k&ouml;nnen zugeordnet werden von:',
'info_racine_site' => 'OBERSTE EBENE DER WEBSITE',
'info_recharger_page' => 'Bitte laden Sie diese Seite in ein paar Augenblicken erneut.',
'info_recherche_auteur_a_affiner' => 'Zu viele Fundstellen f&uuml;r R20;@cherche_auteur@R21; - bitte grenzen Sie die Suche ein.',
'info_recherche_auteur_ok' => 'Zu &bdquo;@cherche_auteur@&ldquo; wurde mehrere Autoren gefunden:',
'info_recherche_auteur_zero' => 'Dem Kriterium “@cherche_auteur@” entspricht kein Autor.',
'info_recommencer' => 'Bitte wiederholen.',
'info_redacteur_1' => 'Redakteur',
'info_redacteur_2' => 'mit Zugang zum Redaktionssystem (<i>empfohlen</i>)',
'info_redacteurs' => 'Redakteure',
'info_redaction_en_cours' => 'IN BEARBEITUNG',
'info_redirection' => 'Umleitung',
'info_referencer_doc_distant' => 'Dokument im Internet verlinken:',
'info_refuses' => 'Ihre abgelehnten Artikel',
'info_reglage_ldap' => 'Optionen: <b>LDAP-Import Einstellungen</b>',
'info_renvoi_article' => '<b>Umleitung.</b> Dieser Artikel zeigt auf die Seite: ',
'info_reserve_admin' => 'Nur Administratoren k&ouml;nnen diese Seite &auml;ndern.',
'info_restauration_sauvegarde' => 'Wiederherstellung der Sicherung @archive@',
'info_restauration_sauvegarde_insert' => 'Einf&uuml;gen der Sicherung @archive@ in die Datenbank',
'info_restreindre_rubrique' => 'Administrationsrechte auf diese Rubrik beschr&auml;nken:',
'info_resultat_recherche' => 'Suchergebnisse:',
'info_rubriques' => 'Rubriken',
'info_rubriques_02' => 'Rubriken',
'info_rubriques_liees_mot' => 'Mit diesem Schlagwort verkn&uuml;pfte Rubriken',
'info_rubriques_trouvees' => 'Rubriken gefunden',
'info_rubriques_trouvees_dans_texte' => 'Rubriken gefunden (im Text)',
'info_sans_titre' => 'Ohne Titel',
'info_sauvegarde' => 'Sicherung',
'info_sauvegarde_articles' => 'Artikel sichern',
'info_sauvegarde_articles_sites_ref' => 'Artikel der verlinkten Sites sichern',
'info_sauvegarde_auteurs' => 'Autoren sichern',
'info_sauvegarde_breves' => 'Meldungen sichern',
'info_sauvegarde_documents' => 'Dokumente sichern',
'info_sauvegarde_echouee' => 'Falls die Sicherung fehlgeschlagen ist(&bdquo;Maximum execution time exceeded&ldquo;),',
'info_sauvegarde_forums' => 'Foren sichern',
'info_sauvegarde_groupe_mots' => 'Schlagwort-Kategorien sichern',
'info_sauvegarde_messages' => 'Nachrichten sichern',
'info_sauvegarde_mots_cles' => 'Schlagworte sichern',
'info_sauvegarde_petitions' => 'Petitionen sichern',
'info_sauvegarde_refers' => 'Referer sichern',
'info_sauvegarde_reussi_01' => 'Sicherung abgeschlossen.',
'info_sauvegarde_reussi_02' => 'Die Datenbank wurde in @archive@ gesichert. Sie k&ouml;nnen ',
'info_sauvegarde_reussi_03' => 'zur Administration',
'info_sauvegarde_reussi_04' => 'Ihrer Site zur&uuml;ckkehren.',
'info_sauvegarde_rubrique_reussi' => 'Die Tabellen der Rubrik @titre@ wurden in der Sicherung @archive@ gespeichert. Sie k&ouml;nnen',
'info_sauvegarde_rubriques' => 'Rubriken sichern',
'info_sauvegarde_signatures' => 'Unterschriften der Petitionen sichern',
'info_sauvegarde_sites_references' => 'Verlinkte Websites sichern',
'info_sauvegarde_type_documents' => 'Dokumenttypen sichern',
'info_sauvegarde_visites' => 'Besucherzahlen sichern',
'info_selection_chemin_acces' => '<b>W&auml;hlen Sie</b> hier den Pfad zu Ihrem Verzeichnis:',
'info_selection_un_seul_mot_cle' => 'In dieser Kategorie kann man nur <b>ein Schlagwort auf einmal</b> ausw&auml;hlen.',
'info_signatures' => 'Unterschriften',
'info_site' => 'Website',
'info_site_2' => 'Website: ',
'info_site_min' => 'Website',
'info_site_propose' => 'Website vorgeschlagen am:',
'info_site_reference_2' => 'Verlinkte Website',
'info_site_syndique' => 'Diese Website ist syndiziert...',
'info_site_valider' => 'Websites, die auf Freigabe warten',
'info_site_web' => 'WEBSITE:',
'info_sites' => 'Websites',
'info_sites_lies_mot' => 'Mit dieser Website verkn&uuml;pfte Schlagworte',
'info_sites_proxy' => 'HTTP-Proxy verwenden',
'info_sites_refuses' => 'Abgelehnte Websites',
'info_sites_trouves' => 'Gefundene Websites',
'info_sites_trouves_dans_texte' => 'Gefundene Websites (im Text)',
'info_sous_titre' => 'Untertitel:',
'info_statut_administrateur' => 'Administrator',
'info_statut_auteur' => 'Status des Autors:',
'info_statut_auteur_a_confirmer' => 'Anmeldung best&auml;tigen',
'info_statut_auteur_autre' => 'Anderer Status:',
'info_statut_efface' => 'Gel&ouml;scht',
'info_statut_redacteur' => 'Redakteur',
'info_statut_site_1' => 'Diese Website ist:',
'info_statut_site_2' => 'Ver&ouml;ffentlicht',
'info_statut_site_3' => 'Vorgeschlagen',
'info_statut_site_4' => 'Gel&ouml;scht',
'info_statut_utilisateurs_1' => 'Vorgegebener Status der importierten Benutzer',
'info_statut_utilisateurs_2' => 'W&auml;hlen Sie den Status, der Personen im LDAP-Verzeichnis zugeordnet wird, wenn sie sich zum ersten Mal anmelden. Sie k&ouml;nnen diesen Wert sp&auml;ter f&uuml;r jeden Autor individuell einstellen.',
'info_suivi_activite' => 'Unterst&uuml;tzung der Redaktionsabl&auml;ufe',
'info_supprimer_mot' => 'Wort l&ouml;schen',
'info_surtitre' => 'Einleitender Titel:',
'info_syndication_integrale_1' => 'Ihre Website biete Backend-Dateien zur Syndikation an (siehe &laquo;&nbsp;<a href="@url@">@titre@</a>&nbsp;&raquo;).',
'info_syndication_integrale_2' => 'M&ouml;chten sie den gesamten Text der Artikel &uuml;berragen oder nur eine Zusammenfassung von ein paar hundert Zeichen?',
'info_table_prefix' => 'Sie k&ouml;nnen den ersten Teil (das Prefix) der Datentabellen &auml;ndern. Das ist unerl&auml;sslich, wenn sie mehrere Websites in der selben Datenbank speichern m&ouml;chten. Das Prefix besteht aus kleinen Buchstaben ohne Akzente, Sonder- oder Leerzeichen',
'info_taille_maximale_images' => 'SPIP wird die maximale Gr&ouml;&szlig;e der Bilder (in Millionen Pixel) testen, die es bearbeiten kann.<br /> Gr&ouml;&szlig;ere Bilder werden nicht verkleinert.',
'info_taille_maximale_vignette' => 'Maximale Gr&ouml;sse der Icons des Systems:',
'info_terminer_installation' => 'Sie k&ouml;nnen jetzt die Standardinstallation abschliessen.',
'info_texte' => 'Text',
'info_texte_explicatif' => 'Beschreibung',
'info_texte_long' => '(Das ist ein langer Text. Er wird in mehreren Teilen angezeigt, die nach der Ver&ouml;ffentlichung zusammen gef&uuml;gt werden.)',
'info_texte_message' => 'Text Ihrer Nachricht:',
'info_texte_message_02' => 'Text Ihrer Nachricht',
'info_titre' => 'Titel:',
'info_titre_mot_cle' => 'Name oder Titel des Schlagworts',
'info_total' => 'Gesamt: ',
'info_tous_articles_en_redaction' => 'Alle Artikel in Bearbeitung',
'info_tous_articles_presents' => 'Alle ver&ouml;ffentlichten Artikel dieser Rubrik',
'info_tous_articles_refuses' => 'Alle abgelehnten Artikel',
'info_tous_les' => 'alle',
'info_tous_redacteurs' => 'Ank&uuml;ndigung f&uuml;r alle Redakteure',
'info_tout_site' => 'Ganze Website',
'info_tout_site2' => 'Der Artikel wurde nicht in diese Sprache &uuml;bersetzt.',
'info_tout_site3' => 'Der Artikel wurde in diese Sprache &uuml;bersetzt, aber der Originalartikel wurde erneut ver&auml;ndert. Die &Uuml;bersetzung muss &uuml;berarbeitet werden.',
'info_tout_site4' => 'Der Artikel wurde in diese Sprache &uuml;bersetzt und die &Uuml;bersetzung ist aktuel.',
'info_tout_site5' => 'Originalartikel.',
'info_tout_site6' => '<b>Achtung:</b> Nur die Originalartikel werden aufgelistet..
Die &Uuml;bersetzungen entsprechen dem Original,
in einer Farbe, die den Status anzeigt&nbsp;:',
'info_travail_colaboratif' => 'Gemeinsame Arbeit an den Artikeln',
'info_un_article' => ' ein Artikel, ',
'info_un_mot' => 'Nur ein Wort auf einmal',
'info_un_site' => ' eine Website, ',
'info_une_breve' => 'Eine Meldung, ',
'info_une_rubrique' => ' eine Rubrik, ',
'info_une_rubrique_02' => '1 Rubrik',
'info_url' => 'URL:',
'info_url_site' => 'URL DER WEBSITE:',
'info_urlref' => 'Hyperlink:',
'info_utilisation_spip' => 'Sie k&ouml;nnen SPIP jetzt verwenden ...',
'info_visites_par_mois' => 'Anzeige pro Monat:',
'info_visites_plus_populaires' => 'Seitenabrufe f&uuml;r die <b>beliebtesten Artikel</b> und die <b>letzten ver&ouml;ffentlichten Artikel:</b>',
'info_visiteur_1' => 'Besucher',
'info_visiteur_2' => 'des &ouml;ffentlichen Bereichs',
'info_visiteurs' => 'Besucher',
'info_visiteurs_02' => 'Besucher des &ouml;ffentlichen Bereichs',
'install_adresse_base_hebergeur' => 'Adresse der vom Provider zugewiesenen Datenbank',
'install_base_ok' => 'Die Datenbank @base@ wurde erkannt',
'install_echec_annonce' => 'Die Installation wird wahrscheinlich fehlschlagen oder eine nicht funktionierende Site ergeben.',
'install_extension_mbstring' => 'SPIP funktioniert nicht mit:',
'install_extension_php_obligatoire' => 'SPIP ben&ouml;tigt die Dateierweiterung php:',
'install_login_base_hebergeur' => 'Vom Provider zugeteilte Login-Daten',
'install_nom_base_hebergeur' => 'Name der vom Provider zugewiesenen Datenbank:',
'install_pas_table' => 'Datenbank zur Zeit ohne Tabellen',
'install_pass_base_hebergeur' => 'Vom Provider zugeteiltes Passwort',
'install_php_version' => 'Die PHP-Version @version@ ist zu alt. (Mindestens erforderlich = @minimum@)',
'install_select_langue' => 'W&auml;hlen Sie eine Sprache aus und klicken Sie auf &laquo;Weiter&raquo;, um die Installation zu starten.',
'install_select_type_db' => 'Geben Sie den Typ der Datenbank an:',
'install_select_type_mysql' => 'MySQL',
'install_select_type_pg' => 'PostgreSQL',
'install_select_type_sqlite2' => 'SQLite 2',
'install_select_type_sqlite3' => 'SQLite 3',
'install_serveur_hebergeur' => 'Vom Provider bereitgestellter Datenbankserver',
'install_table_prefix_hebergeur' => 'Prefix der vom Provider zugeteilten Tabelle',
'install_tables_base' => 'Tabellen der Datenbank',
'install_types_db_connus' => 'SPIP kann <b>MySQL</b> (am weitesten verbreitet), <b>PostgreSQL</b> und <b>SQLite</b> verwenden.',
'install_types_db_connus_avertissement' => 'Achtung: Mehrere Plugins ben&ouml;tigen MySQL',
'intem_redacteur' => 'Redakteur',
'intitule_licence' => 'Lizenz',
'item_accepter_inscriptions' => 'Anmeldungen erlauben',
'item_activer_forum_administrateur' => 'Admin-Forum aktivieren',
'item_activer_messages_avertissement' => 'Aktuelle Benachrichtigungen einschalten',
'item_administrateur_2' => 'Administrator',
'item_afficher_calendrier' => 'Im Kalender anzeigen',
'item_ajout_mots_cles' => 'Schlagworte der Foren erlauben',
'item_autoriser_documents_joints' => 'Dokumente zu Artikeln erlauben',
'item_autoriser_documents_joints_rubriques' => 'Dokumente zu Rubriken erlauben',
'item_autoriser_selectionner_date_en_ligne' => 'Festlegen eines Datums f&uuml;r jedes Dokument gestatten',
'item_autoriser_syndication_integrale' => 'Vollst&auml;ndige Artikel im Feed &uuml;bertragen',
'item_bloquer_liens_syndiques' => 'Syndizierte Websites bis zur Freigabe sperren',
'item_breve_refusee' => 'NEIN - Meldung abgelehnt',
'item_breve_validee' => 'JA - Meldung freigegeben',
'item_choix_administrateurs' => 'Administratoren',
'item_choix_generation_miniature' => 'Vorschaubilder automatisch generieren.',
'item_choix_non_generation_miniature' => 'Keine Vorschaubilder generieren.',
'item_choix_redacteurs' => 'Redakteure',
'item_choix_visiteurs' => 'Besucher im &ouml;ffentlichen Bereich',
'item_compresseur' => 'Kompression aktivieren',
'item_config_forums_prive_global' => 'Forum der Redakteure aktivieren',
'item_config_forums_prive_objets' => 'Diese Foren aktivieren',
'item_creer_fichiers_authent' => '.htpasswd-Dateien anlegen',
'item_desactiver_forum_administrateur' => 'Admin-Forum abschalten',
'item_gerer_annuaire_site_web' => 'Website-Verzeichnis verwalten',
'item_gerer_statistiques' => 'Statistiken verwalten',
'item_limiter_recherche' => 'Suche auf eigene Website begrenzen',
'item_login' => 'Login',
'item_messagerie_agenda' => 'Nachrichtenfunktion des Kalenders aktivieren',
'item_mots_cles_association_articles' => 'Artikeln zuordnen',
'item_mots_cles_association_breves' => 'Meldungen zuordnen',
'item_mots_cles_association_rubriques' => 'Rubriken zuordnen',
'item_mots_cles_association_sites' => 'syndizierten Websites zuordnen.',
'item_non' => 'Nein',
'item_non_accepter_inscriptions' => 'Anmeldungen verhindern',
'item_non_activer_messages_avertissement' => 'Keine aktuellen Benachrichtigungen',
'item_non_afficher_calendrier' => 'Nicht im Kalender anzeigen',
'item_non_ajout_mots_cles' => 'Verwendung von Schlagworten f&uuml;r Foren verhindern',
'item_non_autoriser_documents_joints' => 'Zuordnung von Dokumenten zu Artikeln abschalten',
'item_non_autoriser_documents_joints_rubriques' => 'Verwendung von Dokumenten in Rubriken abschalten',
'item_non_autoriser_selectionner_date_en_ligne' => 'Das Datum der Dokumente entspricht dem Zeitpunkt des Uploads.',
'item_non_autoriser_syndication_integrale' => 'Nur Zusammenfassung &uuml;bertragen',
'item_non_bloquer_liens_syndiques' => 'Links zu syndizierten Websites nicht sperren',
'item_non_compresseur' => 'Kompression abschalten',
'item_non_config_forums_prive_global' => 'Forum der Redakteure abschalten',
'item_non_config_forums_prive_objets' => 'Diese Foren desaktivieren',
'item_non_creer_fichiers_authent' => 'Diese Dateien nicht anlegen',
'item_non_gerer_annuaire_site_web' => 'Website-Verzeichnis abschalten',
'item_non_gerer_statistiques' => 'Keine Statistiken anlegen',
'item_non_limiter_recherche' => 'Inhalt verlinkter Websites in die Suchmaschine aufnehmen',
'item_non_messagerie_agenda' => 'Nachrichtenfunktion des Kalenders abschalten',
'item_non_publier_articles' => 'Artikel nicht vor dem eingestellten Datum ver&ouml;ffentlichen.',
'item_non_utiliser_breves' => 'Keine Meldungen verwenden.',
'item_non_utiliser_config_groupe_mots_cles' => 'Keine erweiterte Schlagwortkonfiguration verwenden.',
'item_non_utiliser_moteur_recherche' => 'Suchmaschine nicht verwenden.',
'item_non_utiliser_mots_cles' => 'Keine Schlagworte verwenden',
'item_non_utiliser_syndication' => 'Keine automatische Syndikation verwenden',
'item_nouvel_auteur' => 'Neuer Autor',
'item_nouvelle_breve' => 'Neue Meldung',
'item_nouvelle_rubrique' => 'Neue Rubrik',
'item_oui' => 'Ja',
'item_publier_articles' => 'Sofort ver&ouml;ffentlichen, egal welches Datum ein Artikel tr&auml;gt. ',
'item_reponse_article' => 'Antwort auf Artikel',
'item_utiliser_breves' => 'Meldungen verwenden',
'item_utiliser_config_groupe_mots_cles' => 'Erweiterte Schlagwortkonfiguration verwenden',
'item_utiliser_moteur_recherche' => 'Suchmaschine verwenden',
'item_utiliser_mots_cles' => 'Schlagworte verwenden',
'item_utiliser_syndication' => 'Automatische Syndikation verwenden',
'item_visiteur' => 'Besucher',

// J
'jour_non_connu_nc' => 'unbekannt',

// L
'lien_ajout_destinataire' => 'Empf&auml;nger hinzuf&uuml;gen',
'lien_ajouter_auteur' => 'Autor hinzuf&uuml;gen',
'lien_ajouter_participant' => 'Teilnehmer hinzuf&uuml;gen',
'lien_email' => 'E-Mail',
'lien_forum_public' => '&Ouml;ffentliches Forum f&uuml;r diesen Artikel verwalten',
'lien_mise_a_jour_syndication' => 'Jetzt aktualisieren',
'lien_nom_site' => 'NAME DER WEBSITE:',
'lien_nouvelle_recuperation' => 'Abruf der Daten erneut versuchen',
'lien_reponse_article' => 'Antwort auf Artikel',
'lien_reponse_breve' => 'Antwort auf Meldung',
'lien_reponse_breve_2' => 'Antwort auf Meldung',
'lien_reponse_rubrique' => 'Antwort auf Rubrik',
'lien_reponse_site_reference' => 'Antwort auf verlinkte Website:',
'lien_retirer_auteur' => 'Autor entfernen',
'lien_retrait_particpant' => 'Teilnehmer entfernen',
'lien_site' => 'Website',
'lien_supprimer_rubrique' => 'Rubrik l&ouml;schen',
'lien_tout_deplier' => 'Alle anzeigen',
'lien_tout_replier' => 'Alle ausblenden',
'lien_tout_supprimer' => 'Alles l&ouml;schen',
'lien_trier_nom' => 'Nach Namen sortieren',
'lien_trier_nombre_articles' => 'Nach Zahl der Artikel sortieren',
'lien_trier_statut' => 'Nach Status sortieren',
'lien_voir_en_ligne' => 'ONLINE ANZEIGEN:',
'logo_article' => 'ARTIKEL-LOGO',
'logo_auteur' => 'AUTOREN-LOGO',
'logo_breve' => 'MELDUNGS-LOGO',
'logo_mot_cle' => 'SCHLAGWORT-LOGO',
'logo_rubrique' => 'RUBRIK-LOGO',
'logo_site' => 'WEBSITE-LOGO',
'logo_standard_rubrique' => 'STANDARD-LOGO F&Uuml;R RUBRIKEN',
'logo_survol' => 'MOUSEOVER-LOGO',

// M
'menu_aide_installation_choix_base' => 'Datenbank ausw&auml;hlen',
'module_fichier_langue' => 'Sprachdatei',
'module_raccourci' => 'Abk&uuml;rzung',
'module_texte_affiche' => 'angezeigter Text',
'module_texte_explicatif' => 'Sie k&ouml;nnen die folgenden Abk&uuml;rzungen in den HTML-Vorlagen Ihrer Website verwenden. Sie werden automatisch in den Sprachen angezeigt, f&uuml;r die eine Sprachdatei existiert.',
'module_texte_traduction' => 'Die Sprachdatei f&uuml;r &laquo;&nbsp;@module@&nbsp;&raquo; liegt vor auf&nbsp;',
'mois_non_connu' => 'unbekannt',

// N
'nouvelles_versions' => 'Neue Versionen von SPIP sind verf&uuml;gbar',

// O
'onglet_contenu' => 'Inhalt',
'onglet_declarer_une_autre_base' => 'Weitere Datenbank deklarieen',
'onglet_discuter' => 'Diskussionen',
'onglet_documents' => 'Dokumente',
'onglet_interactivite' => 'Interaktivit&auml;t',
'onglet_proprietes' => 'Eigenschaften',
'onglet_repartition_actuelle' => 'zur Zeit',
'onglet_sous_rubriques' => 'Unterrubriken',
'ortho_ajouter_ce_mot' => 'Wort zum W&ouml;rterbuch hinzuf&uuml;gen',
'ortho_aucune_suggestion' => 'F&uuml;r dieses Wort wurde kein Vorschlag gefunden.',
'ortho_avis_privacy' => 'SPIP hat eine integrierte Rechtschreibkorrektur. Vor dem Aktivieren lesen sie bitte diesen Text aufmerksam durch:',
'ortho_avis_privacy2' => 'Damit die Rechtschreibung eines Texts &uuml;berpr&uuml;ft werden kann, schickt SPIP die Worte an &laquo;Orthographieserver&raquo;, die von Mitgliedern der SPIP-Gemeinde zur Verf&uuml;gung gestellt werden. Die Worte werden in zuf&auml;lliger Reihenfolge &uuml;bertragen, um ein Maximun an Vertraulichkeit zu erm&ouml;glichen. Wenn Ihnen diese Methode nicht sicher genug ist, verzichten sie bitte darauf, die Rechtschreibpr&uuml;fung zu aktivieren (und entfernen ihre Informationen sofort aus dem Internet).',
'ortho_ce_mot_connu' => 'Dieses Wort steht im W&ouml;rterbuch der Website.',
'ortho_dico_absent' => 'F&uuml;r diese Sprache wurde kein W&ouml;rterbuch gefunden.',
'ortho_mode_demploi' => 'Nicht erkannte Worte sind rot markiert. Sie k&ouml;nnen auf jedes Wort klicken, um die Korrekturvorschl&auml;ge anzuzeigen.',
'ortho_mots_a_corriger' => 'Zu korrigieren',
'ortho_orthographe' => 'Orthographie',
'ortho_supprimer_ce_mot' => 'Wort aus dem W&ouml;rerbuch l&ouml;schen',
'ortho_trop_de_fautes' => 'Achtung: Ihr Text enth&auml;lt zu viele Fehler. Es wurden keine Korrekturvorschl&auml;ge gemacht, um das System nicht zu &uuml;berlasten.',
'ortho_verif_impossible' => 'Das System kann die Rechtschreibung dieses Texts nicht pr&uuml;fen.',
'ortho_verifier' => 'Rechtschreibung pr&uuml;fen',

// P
'page_pas_proxy' => 'Diese Seite darf nicht durch den Proxy &uuml;bertragen werden.',
'pas_de_proxy_pour' => 'Falls erforderlich, k&ouml;nne Sie die Rechner und Domainen angeben, die nicht &uuml;ber den Proxy angesprochen werden (z.B. @exemple@)',
'plugin_charge_paquet' => 'Paket @name@ wird geladen',
'plugin_charger' => '&Uuml;bertragen',
'plugin_erreur_charger' => 'Fehler: @zip@ kann nicht geladen werden',
'plugin_erreur_droit1' => 'In das Verzeichnis <code>@dest@</code> kann nicht geschrieben werden.',
'plugin_erreur_droit2' => 'Bitte &uuml;berpr&uuml;fen Sie die Schreibrechte f&uuml;r dieses Verzeichnis oder legen Sie es an, falls es noch nicht existiert, oder installieren Sie die Dateien per FTP.',
'plugin_erreur_zip' => 'Pclzip fehlgeschlagen: Fehler @status@',
'plugin_etat_developpement' => 'In Entwicklung',
'plugin_etat_experimental' => 'Experimentell',
'plugin_etat_stable' => 'Stabil',
'plugin_etat_test' => 'Im Test',
'plugin_impossible_activer' => 'Das Plugin @plugin@ kann nicht aktiviert werden.',
'plugin_info_automatique1' => 'Wenn Sie die automatische Installation von Plugins nutzen m&ouml;chten, f&uuml;hren Sie bitte folgende Schritte aus:',
'plugin_info_automatique1_lib' => 'Wenn diese Bibliothek automatisch installiert werden soll, f&uuml;hren sie bitte diese Schritte aus:',
'plugin_info_automatique2' => 'Anlegen des Verzeichnis <code>@rep@</code>&nbsp;;',
'plugin_info_automatique3' => '&uuml;berpr&uuml;fen, ob der Server in das Verzeichnis schreiben kann.',
'plugin_info_automatique_creer' => 'im Wurzelverzeichnis der Website.',
'plugin_info_automatique_exemples' => 'Beispiele:',
'plugin_info_automatique_ftp' => 'Sie k&ouml;nnen Plugins per FTP in dem Vezeichnis <tt>@rep@</tt> installieren',
'plugin_info_automatique_lib' => 'Manche Plugins ben&ouml;tigen das Verzeichnis <code>lib/</code>, um Dateien downloaden zu k&ouml;nnen, das im Wurzelverzeichnis der Website angelegt werden muss.',
'plugin_info_automatique_liste' => 'Ihre Plugin-Listen:',
'plugin_info_automatique_liste_officielle' => 'Die offiziellen Plugins',
'plugin_info_automatique_liste_update' => 'Listen aktualisieren',
'plugin_info_automatique_ou' => 'oder...',
'plugin_info_automatique_select' => 'W&auml;hlen Sie ein Plugin aus. SPIP wird es herunterladen und im Verzeichnis <code>@rep@</code> installieren. Falls das Plugin bereits installiert ist, wird es auf den neuesten Stand gebracht.',
'plugin_info_extension_1' => 'Diese Erweiterungen liegen im Verzeichnis @extensions@ und sind aktiviert.',
'plugin_info_extension_2' => 'Man kann sie nicht deaktivieren.',
'plugin_info_telecharger' => 'herunterladen von @url@ und in @rep@ installieren',
'plugin_librairies_installees' => 'Installierte Bibliotheken',
'plugin_necessite_lib' => 'Dieses Plugin ben&ouml;tigt die Bibliothek @lib@',
'plugin_necessite_plugin' => 'Ben&ouml;tigt mindestens Version @version@ des Plugin @plugin@.',
'plugin_necessite_spip' => 'Ben&ouml;tigt mindestens Version @version@ von SPIP.',
'plugin_source' => 'Quelle:&nbsp;',
'plugin_titre_automatique' => 'Automatische Installation',
'plugin_titre_automatique_ajouter' => 'Plugins hinzuf&uuml;gen',
'plugin_titre_installation' => 'Installation des Plugins @plugin@',
'plugin_zip_active' => 'Weiter zum Aktivieren',
'plugin_zip_adresse' => 'Geben Sie hier die Adresse einer ZIP-Datei, die das Plugin enth&auml;lt, oder die Adresse einer Plugin-Liste an.',
'plugin_zip_adresse_champ' => 'Adresse des Plugins oder der Liste&nbsp;',
'plugin_zip_content' => 'Enth&auml;lt die folgenden Dateien (@taille@),<br />die im Verzeichnis <code>@rep@</code> installiert werden k&ouml;nnen.',
'plugin_zip_installe_finie' => 'Die Datei @zip@ wurde entpackt und installiert.',
'plugin_zip_installe_rep_finie' => 'Die Datei @zip@ wurde entpackt und in das Verzeichnis @rep@ installiert.',
'plugin_zip_installer' => 'Sie k&ouml;nnen es jetzt installieren.',
'plugin_zip_telecharge' => 'Die Datei @zip@ wurde heruntergeladen',
'plugins_actif_aucun' => 'Kein aktives Plugin.',
'plugins_actif_un' => 'Ein aktives Plugin.',
'plugins_actifs' => '@count@ aktive Plugins.',
'plugins_actifs_liste' => 'Aktive Plugins',
'plugins_compte' => '@count@ Plugins',
'plugins_disponible_un' => 'Ein Plugin verf&uuml;gbar.',
'plugins_disponibles' => '@count@ verf&uuml;gbare Plugins.',
'plugins_erreur' => 'Fehler in den Plugins: @plugins@',
'plugins_liste' => 'Liste der Plugins',
'plugins_liste_extensions' => 'Erweiterungen',
'plugins_recents' => 'Neueste Plugins.',
'plugins_vue_hierarchie' => 'Hierarchie',
'plugins_vue_liste' => 'Liste',
'protocole_ldap' => 'Version des Protokolls:',

// R
'repertoire_plugins' => 'Verzeichnis:',

// S
'sans_heure' => 'Ohne Zeit',
'sauvegarde_fusionner' => 'Aktuelle Datenbank und Sicherungskopie zusammenf&uuml;hren',
'sauvegarde_fusionner_depublier' => 'Zusammengef&uuml;hrte Objekte offline stellen',
'sauvegarde_url_origine' => 'Wenn gew&uuml;nscht URL der Quelle:',
'statut_admin_restreint' => '(Rubrik-Admin)',
'syndic_choix_moderation' => 'Was soll mit weiteren Links dieser Seite geschehen?',
'syndic_choix_oublier' => 'Was soll mit Links geschehen, die nicht mehr im Feed &uuml;bertragen werden?',
'syndic_choix_resume' => 'Manche Websites &uuml;bertragen den vollst&auml;ndigen Text von Artikeln. In welcher Form m&ouml;chten sie diese Artikel &uuml;bernehmen:',
'syndic_lien_obsolete' => 'veralteter Link',
'syndic_option_miroir' => 'automatisch sperren',
'syndic_option_oubli' => 'nach @mois@&nbsp;Monaten l&ouml;schen',
'syndic_option_resume_non' => 'Den vollst&auml;ndigen Inhalt der Artikel (im HTML-Format)',
'syndic_option_resume_oui' => 'Eine einfache Zusammenfassung (im Textformat)',
'syndic_options' => 'Syndikation - Optionen:',

// T
'taille_cache_image' => 'Dei von SPIP automatisch berechneten Grafiken (Icons f&uuml;r Dokumente, als Grafiken gespeicherte Titel, mathematische Ausdr&uuml;cke im Format TeX...) belegen insgesamt @taille@ im Verzeichnis @dir@.',
'taille_cache_infinie' => 'Die Gr&ouml;sse des <code>CACHE/</code> dieser Website wird nicht begrenzt.',
'taille_cache_maxi' => 'SPIP versucht die Gr&ouml;sse des <code>CACHE/</code> der Website auf ca. <b>@octets@</b> Byte zu begrenzen.',
'taille_cache_octets' => 'Aktuelle Gr&ouml;sse des Cache: @octets@ Byte',
'taille_cache_vide' => 'Der Cache ist leer.',
'taille_repertoire_cache' => 'Gr&ouml;sse des Cache-Verzeichnis',
'text_article_propose_publication' => 'Dieser Artikel ist zur Ver&ouml;ffentlichung vorgeschlagen.',
'text_article_propose_publication_forum' => 'Bitte schreiben Sie Ihren Kommentar in das Forum zu diesem Artikel (unten auf der Seite).',
'texte_acces_ldap_anonyme_1' => 'Manche LDAP-Server erlauben keinen anonymen Zugriff. In diesem Fall muss man Zugangsdaten f&uuml;r die erste Anmeldung eingeben, um Informationen im Verzeichnis suchen zu k&ouml;nnen. Meistens kann man hingegen die folgenden Felder frei lassen.',
'texte_admin_effacer_01' => 'Dieser Befehl l&ouml;scht den <i>gesamten</i> Inhalt der Datenbank mit <i>allen</i> Redakteuren und Administratoren. Nach der Ausf&uuml;hrung dieses Befehls m&uuml;ssen Sie SPIP neu installieren und einen ersten Administrator anlegen.',
'texte_admin_effacer_stats' => 'Dieser Befehl l&ouml;scht alle Daten der Besucherstatistiken, auch die zur Popularit&auml;t der Artikel.',
'texte_admin_tech_01' => 'Diese Option erm&ouml;glicht es, den Inhalt der Datenbank in das Verzeichnis @dossier@ zu sichern. Vergessen Sie bitte nicht, ebenfalls den Inhalt des Verzeichnisses <i>img/</i> zu sichern, denn es enth&auml;lt die Bilder und Grafiken, welche f&uuml;r Rubriken und Artikel verwendet werden.',
'texte_admin_tech_02' => 'Achtung: Diese Sicherungskopie kann AUSSCHLIESSLICH in eine Website wieder eingespielt werden, die unter der gleichen Version von SPIP l&auml;uft.  So darf insbesondere die Datenbank vor einem Update nicht "geleert" werden. Bitte verwenden Sie keine Sicherungskopie, um den Inhalt einer Website nach einem Update wieder einzuspielen. Mehr dazu steht in der <a href="@spipnet@">die SPIP Dokumentation</a>.',
'texte_admin_tech_03' => 'Sie k&ouml;nnen die Daten in komprimierter Form sichern und damit Speicherplatz auf dem Server und Downloadzeit sparen.',
'texte_admin_tech_04' => 'Um das Zusammenf&uuml;hren mit einer anderen Datenbank vorzubereiten, k&ouml;nnen Sie die Datensicherung auf eine bestimmte Rubrik beschr&auml;nken: ',
'texte_adresse_annuaire_1' => '(Wenn Ihr Verzeichnis auf dem selben Rechner installiert ist wie diese Website, m&uuml;ssen Sie wahrscheinlich &bdquo;localhost&ldquo; angeben.)',
'texte_ajout_auteur' => 'Folgender Autor ist diesem Artikel zugeordnet worden:',
'texte_annuaire_ldap_1' => 'Wenn Sie Zugang zu einem LDAP-Verzeichnis haben, k&ouml;nnen Sie es verwenden, um Benutzer automatisch nach SPIP zu importieren.',
'texte_article_statut' => 'Dieser Artikel ist:',
'texte_article_virtuel' => 'Virtueller Artikel',
'texte_article_virtuel_reference' => '<b>Virtueller Artikel:</b> Dieser Artikel ist Teil Ihrer Website, leitet Besucher aber zu einer anderen URL um. Sie k&ouml;nnen die Umleitung abschalten, indem Sie den URL oben l&ouml;schen.',
'texte_aucun_resultat_auteur' => 'Kein Ergebnis f&uuml;r &#8220;@cherche_auteur@&#8221;',
'texte_auteur_messagerie' => 'Die Website kann Ihnen eine Liste aktuell eingelogter Redakteure anzeigen, so dass Sie sofort miteinander in Kontakt treten k&ouml;nnen (Wenn das Nachrichtensystem abgeschaltet ist, gibt es auch keine Liste angemeldeter Redakteure). Sie haben die M&ouml;glichkeit, nicht in diese Liste aufgenommen zu werden (damit sind Sie f&uuml;r andere Benutzer "unsichtbar").',
'texte_auteur_messagerie_1' => 'Diese Webbsite erm&ouml;glicht den Austausch interner Nachrichten und das Anlegen von Foren f&uuml;r Diskussionen zwischen Teilnehmern der Site. Sie k&ouml;nnen Ihre Teilnahme daran abschalten.',
'texte_auteurs' => 'AUTOREN',
'texte_breves' => 'Meldungen sind kurze einfache Texte, um schnell und unkompliziert Nachrichten, eine Presseschau oder einen Veranstaltungskalender zu publizieren ...',
'texte_choix_base_1' => 'W&auml;hlen Sie die Datenbank:',
'texte_choix_base_2' => 'Der SQL-Server enth&auml;lt mehrere Datenbanken.',
'texte_choix_base_3' => '<b>W&auml;hlen</b> Sie die von Ihrem Webhoster f&uuml;r Sie angelegte aus:',
'texte_choix_table_prefix' => 'Prefix der Tabellen:',
'texte_commande_vider_tables_indexation' => 'Verwenden Sie diese Funktion, um die Tabellen der integrierten Suchmaschine zu l&ouml;schen. Damit sparen Sie Speicherplatz.',
'texte_comment_lire_tableau' => 'Die Position eines Artikels wird durch einen Balken angezeigt. Seine Popularit&auml;t (eine Sch&auml;tzung der t&auml;glichen Besucher im Fall, dass die Zugriffe konstant bleiben) und die Anzahl der Besuche von Anfang an werden angezeigt, wenn der Mauszeiger &uuml;ber den Titel bewegt wird.',
'texte_compacter_avertissement' => 'Achtung: Bitte aktivieren Sie diese Option nicht w&auml;hrend der Entwicklung Ihrer Site. Die komprimierten Elemente verlieren dadurch ihre Lesbarkeit.',
'texte_compacter_script_css' => 'SPIP kann Javascripte und CSS Stilvorlagen komprimieren. Dadurch wird die Anzeigegeschwindigkeit der Website erh&ouml;ht.',
'texte_compresse_ou_non' => '(kann komprimiert oder unkomprimiert sein)',
'texte_compresseur_page' => 'SPIP kann alle Seiten, die zum Besucher &uuml;bertragen werden
komprimieren.Diese Einstellung erm&ouml;glicht es, Bandbreite zu sparen (Die
Site wird &uuml;ber langsame Verbindungen schneller angezeigt), ben&ouml;tigt
jedoch zus&auml;tzliche Serverleistung.',
'texte_compte_element' => '@count@ Element',
'texte_compte_elements' => '@count@ Elemente',
'texte_config_groupe_mots_cles' => 'M&ouml;chten Sie die erweiterten Einstellungen f&uuml;r
 Schlagworte einschalten? Sie k&ouml;nnen dann z.B. die Zuordnungen auf ein Wort
 pro Kategorie begrenzen, eine Kategorie als besonders wichtig definieren etc.',
'texte_conflit_edition_correction' => 'Bitte &uuml;berpr&uuml;fen sie hier die Unterschiede zwischen zwei Versionen des Textes. Sie k&ouml;nnen Ihre &Auml;nderungen kopieren und neu eingeben.',
'texte_connexion_mysql' => 'Sie erhalten die erforderlichen SQL-Zugangsdaten von Ihrem Provider: Name des Datenbankservers und pers&ouml;nliche Zugangsdaten.',
'texte_contenu_article' => '(Zusammenfassung des Artikels in wenigen Worten.)',
'texte_contenu_articles' => 'Ja nach Vorlage, die Sie f&uuml;r Ihre Website verwenden, k&ouml;nnen Sie Elemente von Artikeln aktivieren oder abschalten. Bitte bestimmen Sie mit dieser Liste, welche Elemente verf&uuml;gbar sein sollen.',
'texte_crash_base' => 'Wenn Ihre Datenbank abgest&uuml;rzt ist, k&ouml;nnen Sie eine automatische Reparatur versuchen.',
'texte_creer_rubrique' => 'Bevor Sie Artikel schreiben k&ouml;nnen,<br /> m&uuml;ssen Sie eine Rubrik anlegen.',
'texte_date_creation_article' => 'ARTIKEL ANGELEGT AM:',
'texte_date_publication_anterieure' => 'DATUM EINER FR&Uuml;HEREN BEARBEITUNG',
'texte_date_publication_anterieure_nonaffichee' => 'Kein Datum einer fr&uuml;heren Bearbeitung anzeigen.',
'texte_date_publication_article' => 'ONLINE VER&Ouml;FFENTLICHT AM:',
'texte_descriptif_petition' => 'Beschreibung der Petition',
'texte_descriptif_rapide' => 'Kurzbeschreibung',
'texte_documents_joints' => 'Sie k&ouml;nnen die Zuordnung von Dokumenten (Office-Dokumente, Bilder, Multimedia-Dateien, etc.) zu Artikeln und/oder Rubriken erlauben. Diese Dokumente k&ouml;nnen anschliessend innerhalb von Artikeln verlinkt oder separat angezeigt werden.<p>',
'texte_documents_joints_2' => 'Diese Einstellung widerspricht nicht dem Einf&uuml;gen von Bildern in Artikel.',
'texte_effacer_base' => 'SPIP-Datenbank l&ouml;schen',
'texte_effacer_donnees_indexation' => 'Indexe l&ouml;schen',
'texte_effacer_statistiques' => 'Statistiken l&ouml;schen',
'texte_en_cours_validation' => 'Die folgenden Artikel und Meldungen sind zur Ver&ouml;ffentlichung vorgeschlagen.',
'texte_en_cours_validation_forum' => 'Bitte schreiben Sie Ihre Kommentare in die entsprechenden Foren.',
'texte_enrichir_mise_a_jour' => 'Sie k&ouml;nnen Ihren Text ansprechend gestalten, indem Sie die &#132;typografischen Abk&uuml;rzungen&#147; verwenden.',
'texte_fichier_authent' => '<b>Soll SPIP die Dateien <tt>.htpasswd</tt> und <tt>.htpasswd-admin</tt> im Verzeichnis @dossier@ anlegen?</b><p>
 Mit diesen Dateien k&ouml;nnen Sie den Zugang zu anderen Bereichen Ihrer Website (z.B. externe Logfile-Auswertungen) auf Redakteure und Administratoren beschr&auml;nken.</p><p>Wenn Sie diese M&ouml;glickeit nicht nutzen, k&ouml;nnn Sie hier die Grundeinstellung (Dateien werden nicht angelegt) beibehalten.</p>',
'texte_informations_personnelles_1' => 'Das System nun pers&ouml;nliche Zugangsdaten f&uuml;r Sie anlegen.',
'texte_informations_personnelles_2' => '(Wenn Sie die Site erneut installieren, und Ihre Zugangsdaten funktionieren, k&ouml;nnen Sie',
'texte_introductif_article' => '(Einleitender Text des Artikels.)',
'texte_jeu_caractere' => 'Es empfiehlt sich, das Universalalphabet (<tt>utf-8</tt>) f&uuml;r ihre Website zu verwenden. Es erm&ouml;glicht die Darstellung der Zeichen aller Sprachen und wird nunmehr von allen modernen Webbrowsern unterst&uuml;tzt.',
'texte_jeu_caractere_2' => 'Achtung: Diese Einstellung bewirkt keine Konvertierung der bereits gespeicherten Texte.',
'texte_jeu_caractere_3' => 'Ihre Website verwendet zur Zeit den Zeichensatz:',
'texte_jeu_caractere_4' => 'Wenn das nicht mit den Erfordernissen ihrer Daten &uuml;bereinstimmt (z.B. nach der Wiederherstellung einer Datensicherung), oder wenn sie die Website neu einrichten und einen anderen Zeichernsatz verwenden m&ouml;chten, stellen sie ihn bitte hier ein:',
'texte_jeu_caractere_conversion' => 'Anmerkung: Wenn sie die texte Ihrer Website endg&uuml;ltig nach <tt>utf-8</tt> umstellen m&ouml;chten, verwenden sie bitte <a href="@url@">die Seite zur Konvertierung nach utf-8</a>.',
'texte_lien_hypertexte' => '(Wenn sich Ihr Beitrag auf einen Artikel im WWW bezieht oder es eine Seite mit Zusatzinformationen gibt, geben Sie bitte die Bezeichnung der Seite und ihren URL an.)',
'texte_liens_sites_syndiques' => 'Links zu syndizierten Websites k&ouml;nnen bis zur Freigabe durch einen Administrator gesperrt bleiben. Hier legen Sie die Grundeinstellung fest. Sie k&ouml;nnen diese Einstellung f&uuml;r jede Site einzeln &auml;ndern, bzw. nach und nach entscheiden, wie die neuen Links einer Website behandelt werden sollen.',
'texte_login_ldap_1' => '(Keine Angabe bzw. vollst&auml;ndiger Pfad, z.B. &bdquo;<tt>uid=meier, ou=mitglieder, dc=MeineDom&auml;ne, dc=com</tt>&ldquo;.)',
'texte_login_precaution' => 'Achtung! Sie sind zur Zeit mit diesem Namen angemeldet. Bitte verwenden Sie diese Seite mit der erforderlichen Vorsicht.',
'texte_message_edit' => 'Achtung! Diese Nachricht kann von allen Administratoren der Website bearbeitet werden und ist f&uuml;r alle Redakteure sichtbar. Verwenden Sie Ank&uuml;ndigungen nur f&uuml;r wichtige Ereignisse, die alle Teilnehmer kennen m&uuml;ssen.',
'texte_messagerie_agenda' => 'Mit dem Nachrichtensystem k&ouml;nnen Redakteure im Redaktionsbereich direkt miteinander kommunizieren. Es ist mit einem Kalender verbunden.',
'texte_messages_publics' => '&Ouml;ffentliche Beitr&auml;ge des Artikels:',
'texte_mise_a_niveau_base_1' => 'Sie haben den Programmcode von SPIP aktualisiert. Jetzt muss die Datenbank aktualisiert werden.',
'texte_modifier_article' => 'Artikel bearbeiten:',
'texte_moteur_recherche_active' => '<b>Die integrierte Suchmaschine ist eingeschaltet.</b> Damit k&ouml;nnen Sie eine erneute Erfassung aller Seiten erzwingen, wenn Sie z.B. wesentliche &Auml;nderungen am Inhalt und Layout Ihrer Site gemacht haben oder eine Sicherungskopie eingespielt haben. Dokumente, die im SPIP Redaktionssystem eingegeben werden, erfasst die Suchmaschine automatisch. Sie ben&ouml;tigen diese Funktion deshalb nur in Ausnahmef&auml;llen.',
'texte_moteur_recherche_non_active' => 'Suchmaschine ist abgeschaltet.',
'texte_mots_cles' => 'Mit Schlagworten k&ouml;nnen Verbindungen zu thematisch verwandten Artikeln hergestellt werden, die sich in einer anderen Rubrik befinden. Dadurch k&ouml;nnen Sie eine flexible Navigationsstruktur schaffen oder in Ihren Layoutvorlagen individuelle Benutzer-Layouts erm&ouml;glichen.',
'texte_mots_cles_dans_forum' => 'D&uuml;rfen Ihre Besucher Forumsbeitr&auml;ge verschlagworten? (Achtung! Diese Option ist komplex und sett genaue Kenntnisse voraus.)',
'texte_multilinguisme' => 'Wenn Sie Artikel in mehreren Sprachen mit entsprecher komplexer Navigation verwalten m&ouml;chten, k&ouml;nnen Sie den Rubriken und/oder den Artikeln ein Men&uuml; zur Sprachauswahl hinzuf&uuml;gen. Diese Funktion ist abh&auml;ngig von der Struktur Ihrer Website.',
'texte_multilinguisme_trad' => 'Sie k&ouml;nnen auch ein System zur automatischen Verlinkung der verschiedenen Sprachversionen eines Artikels aktivieren.',
'texte_non_compresse' => '<i>unkomprimiert</i> (ihr Server unterst&uuml;tzt diese Funktion nicht)',
'texte_non_fonction_referencement' => 'Sie k&ouml;nnen diese automatische Funktion ignorieren und die f&uuml;r Ihre Website wichtigen Elemente selber angeben ...',
'texte_nouveau_message' => 'Neue Nachricht',
'texte_nouveau_mot' => 'Neues Wort',
'texte_nouvelle_version_spip_1' => 'Sie haben eine neue Version von SPIP installiert.',
'texte_nouvelle_version_spip_2' => 'Diese neue Version erfordert eine weiter gehende Aktualisierung Ihres Systems als gew&ouml;hnlich. Wenn Sie Webmaster dieser Site sind, l&ouml;schen Sie bitte die Datei @connect@ und setzen Sie die Installation fort, indem Sie die Verbindungsdaten zur Datenbank neu eingeben.<p>(Tipp: Sollten Sie Ihre Verbindungsdaten vergessen haben, schauen Sie in der Datei @connect@ nach, bevor Sie sie l&ouml;schen ...)</p>',
'texte_operation_echec' => 'Gehen Sie zur vorigen Seite zur&uuml;ck und w&auml;hlen Sie eine andere Datenbank aus bzw. legen Sie eine neue an. &Uuml;berpr&uuml;fen Sie die Angaben Ihres Providers.',
'texte_plus_trois_car' => 'mehr als 3 Zeichen',
'texte_plusieurs_articles' => 'Mehrere Autoren f&uuml;r &bdquo;@cherche_auteur@&ldquo; gefunden:',
'texte_port_annuaire' => '(Der Standardwert kann meistens beibehalten werden.)',
'texte_presente_plugin' => 'Diese Seite zeigt eine Liste der auf dieser Website verf&uuml;gbaren Plugins. Sie k&ouml;nnen sie aktivieren, indem sie die entsprechenden Eintr&auml;ge mit einem H&auml;kchen merkieren.',
'texte_proposer_publication' => 'Wenn Ihr Artikel fertig ist,<br /> k&ouml;nnen Sie ihn zur Ver&ouml;ffentlichung vorschlagen.',
'texte_proxy' => 'In manchen F&auml;llen (Intranet, Rechner hinter einer Firewall...),
kann ein <i>HTTP-Proxy</i> erforderlich sein, um die syndizierten Websites zu erreichen.
 In diesem Fall geben Sie seine Adresse im Format
<tt><html>http://proxy:8080</html></tt>. an.
Meistens kann dieses Feld aber leer bleiben.',
'texte_publication_articles_post_dates' => 'Wie soll SPIP Artikel behandeln, deren Erscheinungsdatum in die Zukunft gelegt wurde?',
'texte_rappel_selection_champs' => '[Vergessen Sie nicht, dieses Feld korrekt auszuf&uuml;llen.]',
'texte_recalcul_page' => 'Wenn Sie nur eine einzelne Seite aktualisieren wollen, verwenden Sie besser den Schalter &bdquo;Seite aus Cache l&ouml;schen&ldquo;.',
'texte_recapitiule_liste_documents' => 'Diese Seite enth&auml;lt eine Liste der Dokumente, die Sie in Rubriken eingeordnet haben. Um die Angaben zu den Dokumenten zu bearbeiten, benutzen Sie bitte den Link zur jeweiligen Rubrik.',
'texte_recuperer_base' => 'Datenbank reparieren',
'texte_reference_mais_redirige' => 'Artikel Ihrer Website, der eine Umleitung zu einem anderen URL enth&auml;lt.',
'texte_referencement_automatique' => '<b>Automatische Verlinkung einer Website</b><br />Sie k&ouml;nnen eine Website im Schnellverfahren verlinken, indem Sie seinen URL oder den seiner Backend-Datei angeben. SPIP wird dann die Daten der Website selbst&auml;ndig einlesen (Titel, Beschreibung ...).',
'texte_referencement_automatique_verifier' => 'Bitte &uuml;berpr&uuml;fen Sie die Informationen von <tt>@url@</tt> vor dem Speichern.',
'texte_requetes_echouent' => '<b>Wenn manche SQL-Befehle ohne ersichtlichen Grund systematisch fehlschlagen, kann es an einer besch&auml;digten Datenbank liegen.</b><p>
SQL kann Tabellen reparieren, die besch&auml;digt worden sind. Starten Sie hier einen Reparaturversuch. Sollte das fehlschlagen, notieren Sie bitte die Fehlermeldung, die u.U. einen Hinweis auf die Ursache des Problems gibt ...<p>
Wenn das Problem weiter besteht, nehmen Sie bitte Kontakt mit Ihrem Provider auf.<p>',
'texte_restaurer_base' => 'Wiederherstellung des Inhalts der Datenbank',
'texte_restaurer_sauvegarde' => 'Mit dieser Funktion k&ouml;nnen Sie eine Sicherungskopie Ihrer Datenbank wieder einspielen. Dazu muss die Sicherungsdatei in das Verzeichnis @dossier@ kopiert werden. Verwenden Sie diese Funktion mit der n&ouml;tigen Vorsicht. <b>Die &Auml;nderungen k&ouml;nnen nicht wieder r&uuml;ckg&auml;ngig gemacht werden.</b>',
'texte_sauvegarde' => 'Inhalt der Datenbank sichern',
'texte_sauvegarde_base' => 'Datenbank sichern',
'texte_sauvegarde_compressee' => 'Die Sicherung wird als unkomprimierte Datei @fichier@ angelegt.',
'texte_selection_langue_principale' => 'Hier k&ouml;nnen Sie die &laquo;Hauptsprache&raquo; der Website ausw&auml;hlen. Das zwingt Sie - zum Gl&uuml;ck - nicht, Ihre Artikel in dieser Sprache zu schreiben, sondern erm&ouml;glicht:
        <ul><li> das Format der Datumsanzeige einzustellen;</li>
        <li> die Art der typografischen Korrekturen von SPIP zu bestimmen;</li>
        <li> &uuml;ber die Sprachversion der eingebauten Formulare zu entscheiden;</li>
        <li> die Standardsprache des Redaktionssystems zu ver&auml;ndern.</li></ul>',
'texte_signification' => 'Die roten Balken stellen die Summe der Eintr&auml;ge dar (Summe der Unterrubriken), die hellen Balken symbolisieren die Anzahl der Seitenabrufe pro Rubrik.',
'texte_sous_titre' => 'Untertitel',
'texte_statistiques_visites' => '(dunkle Balken : Sonntag / dunkle Kurve : Entwicklung der Durchschnittswerte)',
'texte_statut_attente_validation' => 'vorgeschlagen',
'texte_statut_publies' => 'ver&ouml;ffentlicht',
'texte_statut_refuses' => 'abgelehnt',
'texte_suppression_fichiers' => 'Benutzen Sie diesen Befehl, um alle Dateien aus dem Zwischenspeicher von SPIP zu l&ouml;schen. Damit k&ouml;nnen Sie eine erneute Berechnung aller Seiten erzwingen, wenn Sie z.B. wesentliche &Auml;nderungen am Inhalt und Layout Ihrer Site gemacht haben. ',
'texte_sur_titre' => 'Einleitender Titel',
'texte_syndication' => 'Manche Websites erm&ouml;glichen den automatischen Abruf einer Liste von neuen Artikeln. Um diese Daten nutzen zu k&ouml;nnen, m&uuml;ssen Sie die Syndikation aktivieren.
                <blockquote><i>Manche Provider unterbinden die Nutzung dieser Funktion. Dann k&ouml;nnen Sie keine syndizierten Inhalte nutzen.</i></blockquote>',
'texte_table_ok' => ': Tabelle OK.',
'texte_tables_indexation_vides' => 'Indextabellen der Suchmaschine sind leer.',
'texte_tentative_recuperation' => 'Reparaturversuch',
'texte_tenter_reparation' => 'Reparatur der Datenbank versuchen',
'texte_test_proxy' => 'Um den Proxy zu testen, geben Sie hier die Adresse einer gew&uuml;nschten Website ein.',
'texte_titre_02' => 'Titel:',
'texte_titre_obligatoire' => '<b>Titel</b> [obligatorisch]',
'texte_travail_article' => '@nom_auteur_modif@ hat diesen Artikel vor @date_diff@ Minuten bearbeitet',
'texte_travail_collaboratif' => 'Wenn es &ouml;fter vorkommt, dass mehrere Redakteure gemeinsam an Artikeln arbeiten, kann SPIP die vor kurzem &bdquo;ge&ouml;ffneten&ldquo; Artikel anzeigen, um gleichzeitige &Auml;nderungen vorzubeugen. Diese Funktion ist normalerweise abgeschaltet, um st&ouml;rende Meldungen zu reduzieren.',
'texte_trop_resultats_auteurs' => 'Zu viele Ergebnisse f&uuml;r &bdquo;@cherche_auteur@&ldquo;. Bitte pr&auml;zisieren Sie Ihre Suchanfrage.',
'texte_type_urls' => 'Hier k&ouml;nnen Sie von SPIP verwendeten Typ URL (Adresse) der Seiten w&auml;hlen.',
'texte_type_urls_attention' => 'Achtung: Diese Einstellung wird nur wirksam, wenn die Datei @htaccess@ im Wurzelverzeichnis der Website vorhanden ist.',
'texte_unpack' => 'neue Version laden.',
'texte_utilisation_moteur_syndiques' => 'Wenn Sie die Suchmaschine von SPIP einsetzen,
 k&ouml;nnen Sie syndizierte Artikel und Websites auf zwei Arten behandeln. <br />- Im einfachsten Fall werden nur Titel und Beschreibung der Artikel durchsucht. <br />-
 Die zweite, wesentlich leistungsf&auml;higere Methode erlaubt es, auch den Text der
 syndizierten Websites zu durchsuchen. Wenn Sie eine Website verlinken, erfasst SPIP vollautomatisch den Inhalt der Website selber. ',
'texte_utilisation_moteur_syndiques_2' => 'Diese Methode zwingt SPIP, die verlinkten Websites in regelm&auml;ssigen Abst&auml;nden abzurufen, wodurch Ihre Website etwas langsamer werden kann.',
'texte_vide' => 'leer',
'texte_vider_cache' => 'Cache leeren',
'titre_admin_effacer' => 'Wartung',
'titre_admin_tech' => 'Wartung',
'titre_admin_vider' => 'Wartung',
'titre_articles_syndiques' => 'Syndizierte Artikel dieser Website',
'titre_breves' => 'Meldungen',
'titre_cadre_afficher_article' => 'Artikel anzeigen',
'titre_cadre_afficher_traductions' => 'Stand der &Uuml;bersetzungen f&uuml;r diese Sprachen anzeigen',
'titre_cadre_ajouter_auteur' => 'AUTOR HINZUF&Uuml;GEN: ',
'titre_cadre_forum_administrateur' => 'Administratorforum',
'titre_cadre_forum_interne' => 'Internes Forum',
'titre_cadre_interieur_rubrique' => 'In der Rubrik',
'titre_cadre_numero_auteur' => 'AUTOR NUMMER',
'titre_cadre_signature_obligatoire' => '<b>Unterschrift</b> [obligatorisch]<br />',
'titre_compacter_script_css' => 'Skripte und CSS komprimieren',
'titre_compresser_flux_http' => 'HTTP-&Uuml;bertragung komprimieren',
'titre_config_contenu_notifications' => 'Benachrichtigungen',
'titre_config_contenu_prive' => 'Im Redaktionsbereich',
'titre_config_contenu_public' => 'Auf der &ouml;ffentlichen Website',
'titre_config_fonctions' => 'Website konfigurieren',
'titre_config_forums_prive' => 'Forum des Redaktionsbereichs',
'titre_config_groupe_mots_cles' => 'Schlagwort-Kategorien einrichten',
'titre_configuration' => 'Website konfigurieren',
'titre_conflit_edition' => 'Bearbeitungskonflikt',
'titre_connexion_ldap' => 'Optionen: <b>LDAP-Verbindung</b>',
'titre_dernier_article_syndique' => 'Neue syndizierte Artikel',
'titre_documents_joints' => 'beigef&uuml;gte Dokumente',
'titre_evolution_visite' => 'Entwicklung der Seitenabrufe',
'titre_forum_suivi' => 'Foren moderieren',
'titre_gauche_mots_edit' => 'WORT NUMMER:',
'titre_groupe_mots' => 'KATEGORIE:',
'titre_langue_article' => 'SPRACHE DES ARTIKELS',
'titre_langue_breve' => 'SPRACHE DER MELDUNG',
'titre_langue_rubrique' => 'SPRACHE DER RUBRIK',
'titre_langue_trad_article' => 'SPRACHE UND &Uuml;BERSETZUNGEN DES ARTIKELS',
'titre_les_articles' => 'ARTIKEL',
'titre_messagerie_agenda' => 'Nachrichten und Kalender',
'titre_mots_cles_dans_forum' => 'Schlagworte in &ouml;ffentlichen Foren',
'titre_mots_tous' => 'Schlagworte',
'titre_naviguer_dans_le_site' => 'Sitenavigation ...',
'titre_nouveau_groupe' => 'Neue Kategorie',
'titre_nouvelle_breve' => 'Neue Meldung',
'titre_nouvelle_rubrique' => 'Neue Rubrik',
'titre_numero_rubrique' => 'RUBRIK NUMMER:',
'titre_page_admin_effacer' => 'Wartung: Datenbank l&ouml;schen',
'titre_page_articles_edit' => 'Bearbeiten: @titre@',
'titre_page_articles_page' => 'Artikel',
'titre_page_articles_tous' => 'Ganze Website',
'titre_page_auteurs' => 'Besucher',
'titre_page_breves' => 'Meldungen',
'titre_page_breves_edit' => 'Meldung bearbeiten: &#8220;@titre@&#8221;',
'titre_page_calendrier' => 'Kalender @nom_mois@ @annee@',
'titre_page_config_contenu' => 'Website konfigurieren',
'titre_page_config_fonctions' => 'Website konfigurieren',
'titre_page_configuration' => 'Website konfigurieren',
'titre_page_controle_petition' => 'Petitionen verwalten',
'titre_page_delete_all' => 'vollst&auml;ndig unwiderruflich l&ouml;schen',
'titre_page_documents_liste' => 'Dokumente in Rubriken',
'titre_page_forum' => 'Administratorforum',
'titre_page_forum_envoi' => 'Nachricht schicken',
'titre_page_forum_suivi' => 'Foren moderieren',
'titre_page_index' => 'Ihr Bereich',
'titre_page_message_edit' => 'Nachricht verfassen',
'titre_page_messagerie' => 'Ihr Nachrichtensystem',
'titre_page_mots_tous' => 'Schlagworte',
'titre_page_recherche' => 'Ergebnisse der Suche nach @recherche@',
'titre_page_sites_tous' => 'Verlinkte Websites',
'titre_page_statistiques' => 'Statistiken pro Rubrik',
'titre_page_statistiques_messages_forum' => 'Forumsbeitr&auml;ge',
'titre_page_statistiques_referers' => 'Statistik (Referer)',
'titre_page_statistiques_signatures_jour' => 'Unterschriften pro Tag',
'titre_page_statistiques_signatures_mois' => 'Unterschriften pro Monat',
'titre_page_statistiques_visites' => 'Statistik der Seitenabrufe',
'titre_page_upgrade' => 'Aktualisierung von SPIP',
'titre_publication_articles_post_dates' => 'Ver&ouml;ffentlichung von vordatierten Artikeln',
'titre_referencement_sites' => 'Verlinkung und Syndikation',
'titre_referencer_site' => 'Website verlinken:',
'titre_rendez_vous' => 'TERMIN:',
'titre_reparation' => 'Reparatur',
'titre_site_numero' => 'WEBSITE NUMMER:',
'titre_sites_proposes' => 'Vorgeschlagene Websites',
'titre_sites_references_rubrique' => 'Verlinkte Websites in dieser Rubrik',
'titre_sites_syndiques' => 'Syndizierte Websites',
'titre_sites_tous' => 'Verlinkte Websites',
'titre_suivi_petition' => 'Petitionen verwalten',
'titre_syndication' => 'Website Syndikation',
'titre_type_urls' => 'URL-Typ',
'tls_ldap' => 'Transport Layer Security:',
'tout_dossier_upload' => 'Das ganze Verzeichnis @upload@',
'trad_article_inexistant' => 'Es gibt keinen Artikel mit dieser Nummer.',
'trad_article_traduction' => 'Alle Fassungen dieses Artikels:',
'trad_deja_traduit' => 'Fehler: Dieser Artikel kann nicht mit der gew&uuml;nschten Nummer verkn&uuml;pft werden.',
'trad_delier' => 'Artikel nicht mehr mit diesen &Uuml;bersetzungen verbinden',
'trad_lier' => 'Dieser Artikel ist eine &Uuml;bersetzung des Artikels Nummer&nbsp;',
'trad_new' => 'Neue &Uuml;bersetzung dieses Artikels beginnen',

// U
'upload_fichier_zip' => 'ZIP-Datei',
'upload_fichier_zip_texte' => 'Sie m&ouml;chsten eine ZIP-Datei installieren.',
'upload_fichier_zip_texte2' => 'SPIP kann:',
'upload_info_mode_document' => 'Bild im Portfolio ablegen',
'upload_info_mode_image' => 'Bild aus dem Portfolio entfernen',
'upload_limit' => 'Datei zu gross zum Hochladen. Maximale <i>upload</i>-Gr&ouml;sse: @max@.',
'upload_zip_conserver' => 'Archiv nach Entpacken beibehalten',
'upload_zip_decompacter' => 'Das ZIP-Archiv auspacken. Diese Dateien werden dann auf dem Server installiert:',
'upload_zip_telquel' => 'Das ZIP-Archiv als eine Archivdatei installieren.',
'upload_zip_titrer' => 'Dateinamen als Titel verwenden',
'utf8_convert_attendez' => 'Warten sie einen Augenblick und laden sie diese Seite erneut.',
'utf8_convert_avertissement' => 'Sie werden ihre Datenbank (Artikel, Meldungen, etc.) vom Zeichensatz <b>@orig@</b> nach <b>@charset@</b> zu konvertieren.',
'utf8_convert_backup' => 'Vergessen sie nicht, zun&auml;chst eine Sicherung ihrer Website anzulegen. Sie sollten ebenfalls &uuml;berpr&uuml;fen, ob ihre Skelette und Sprachdateien zum Zeichensatz @charset@ kompatibel sind.',
'utf8_convert_erreur_deja' => 'Ihre website verwendet bereits den zeichensatz @charset@. Die Konvertierung ist &uuml;berfl&uuml;ssig.',
'utf8_convert_erreur_orig' => 'Fehler: Der Zeichensatz @charset@ wird nicht unterst&uuml;tzt.',
'utf8_convert_termine' => 'Fertig!',
'utf8_convert_timeout' => '<b>Wichtig:</b> Im Falle eines <i>timeout</i> des Servers, laden sie diese Seite so lange neu, bis &laquo;Fertig&raquo; angezeigt wird.',
'utf8_convert_verifier' => 'Sie m&uuml;ssen nun den Cache leeren und  das Verhalten ihrer &ouml;ffentlich zug&auml;nglichen Seiten &uuml;berpr&uuml;fen. Falls es ernste Probleme damit geben sollte, steht ihnen eine Sicherungskopie ihrer Daten (im SQL-Format) im Verzeichnis @rep@ zur Verf&uuml;gung.',
'utf8_convertir_votre_site' => 'Website nach utf-8 konvertieren',

// V
'version' => 'Version:',
'version_deplace_rubrique' => 'Verschoben von <b>&laquo;&nbsp;@from@&nbsp;&raquo;</b> nach <b>&laquo;&nbsp;@to@&nbsp;&raquo;</b>.',
'version_initiale' => 'Urspr&uuml;ngliche Fassung'
);

?>
